"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def get(hub, ctx, job_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Returns the UnlockCode code value for the specified job. A particular UnlockCode value can be accessed for up to 360 days after the associated job has been created. The UnlockCode value is a 29-character code with 25 alphanumeric characters and 4 hyphens. This code is used to decrypt the manifest file when it is passed along with the manifest to the Snow device through the Snowball client when the client is started for the first time. As a best practice, we recommend that you don't save a copy of the UnlockCode in the same location as the manifest file for that job. Saving these separately helps prevent unauthorized parties from gaining access to the Snow device associated with that job.

    Args:
        job_id(str): The ID for the job that you want to get the UnlockCode value for, for example JID123e4567-e89b-12d3-a456-426655440000.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.snowball.job.unlock_code.get(ctx, job_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.snowball.job.unlock_code.get job_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="snowball",
        operation="get_job_unlock_code",
        op_kwargs={"JobId": job_id},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def publish(
    hub,
    ctx,
    function_name: str,
    code_sha256: str = None,
    description: str = None,
    revision_id: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a version from the current code and configuration of a function. Use versions to create a snapshot of your function code and configuration that doesn't change. Lambda doesn't publish a version if the function's configuration and code haven't changed since the last version. Use UpdateFunctionCode or UpdateFunctionConfiguration to update the function before publishing a version. Clients can invoke versions directly or with an alias. To create an alias, use CreateAlias.

    Args:
        function_name(str): The name of the Lambda function.  Name formats     Function name - MyFunction.    Function ARN - arn:aws:lambda:us-west-2:123456789012:function:MyFunction.    Partial ARN - 123456789012:function:MyFunction.   The length constraint applies only to the full ARN. If you specify only the function name, it is limited to 64 characters in length.
        code_sha256(str, optional): Only publish a version if the hash value matches the value that's specified. Use this option to avoid publishing a version if the function code has changed since you last updated it. You can get the hash for the version that you uploaded from the output of UpdateFunctionCode. Defaults to None.
        description(str, optional): A description for the version to override the description in the function configuration. Defaults to None.
        revision_id(str, optional): Only update the function if the revision ID matches the ID that's specified. Use this option to avoid publishing a version if the function configuration has changed since you last updated it. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.lambda_.version.init.publish(ctx, function_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.lambda_.version.init.publish function_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="lambda",
        operation="publish_version",
        op_kwargs={
            "FunctionName": function_name,
            "CodeSha256": code_sha256,
            "Description": description,
            "RevisionId": revision_id,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def batch(hub, ctx, connection_name_list: List, catalog_id: str = None) -> Dict:
    r"""
    **Autogenerated function**

    Deletes a list of connection definitions from the Data Catalog.

    Args:
        catalog_id(str, optional): The ID of the Data Catalog in which the connections reside. If none is provided, the Amazon Web Services account ID is used by default. Defaults to None.
        connection_name_list(List): A list of names of the connections to delete.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.glue.delete.connection.batch(ctx, connection_name_list=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.glue.delete.connection.batch connection_name_list=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="glue",
        operation="batch_delete_connection",
        op_kwargs={"CatalogId": catalog_id, "ConnectionNameList": connection_name_list},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub,
    ctx,
    group_name: str,
    filter_expression: str = None,
    insights_configuration: Dict = None,
    tags: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a group resource with a name and a filter expression.

    Args:
        group_name(str): The case-sensitive name of the new group. Default is a reserved name and names must be unique.
        filter_expression(str, optional): The filter expression defining criteria by which to group traces. Defaults to None.
        insights_configuration(Dict, optional): The structure containing configurations related to insights.   The InsightsEnabled boolean can be set to true to enable insights for the new group or false to disable insights for the new group.   The NotifcationsEnabled boolean can be set to true to enable insights notifications for the new group. Notifications may only be enabled on a group with InsightsEnabled set to true.  . Defaults to None.
        tags(List, optional): A map that contains one or more tag keys and tag values to attach to an X-Ray group. For more information about ways to use tags, see Tagging AWS resources in the AWS General Reference. The following restrictions apply to tags:   Maximum number of user-applied tags per resource: 50   Maximum tag key length: 128 Unicode characters   Maximum tag value length: 256 Unicode characters   Valid values for key and value: a-z, A-Z, 0-9, space, and the following characters: _ . : / = + - and @   Tag keys and values are case sensitive.   Don't use aws: as a prefix for keys; it's reserved for AWS use.  . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.xray.group.create(ctx, group_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.xray.group.create group_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="xray",
        operation="create_group",
        op_kwargs={
            "GroupName": group_name,
            "FilterExpression": filter_expression,
            "InsightsConfiguration": insights_configuration,
            "Tags": tags,
        },
    )


async def delete(hub, ctx, group_name: str = None, group_arn: str = None) -> Dict:
    r"""
    **Autogenerated function**

    Deletes a group resource.

    Args:
        group_name(str, optional): The case-sensitive name of the group. Defaults to None.
        group_arn(str, optional): The ARN of the group that was generated on creation. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.xray.group.delete(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.xray.group.delete
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="xray",
        operation="delete_group",
        op_kwargs={"GroupName": group_name, "GroupARN": group_arn},
    )


async def get(hub, ctx, group_name: str = None, group_arn: str = None) -> Dict:
    r"""
    **Autogenerated function**

    Retrieves group resource details.

    Args:
        group_name(str, optional): The case-sensitive name of the group. Defaults to None.
        group_arn(str, optional): The ARN of the group that was generated on creation. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.xray.group.get(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.xray.group.get
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="xray",
        operation="get_group",
        op_kwargs={"GroupName": group_name, "GroupARN": group_arn},
    )


async def get_all(hub, ctx, next_token: str = None) -> Dict:
    r"""
    **Autogenerated function**

    Retrieves all active group details.

    Args:
        next_token(str, optional): Pagination token. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.xray.group.get_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.xray.group.get_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="xray",
        operation="get_groups",
        op_kwargs={"NextToken": next_token},
    )


async def update(
    hub,
    ctx,
    group_name: str = None,
    group_arn: str = None,
    filter_expression: str = None,
    insights_configuration: Dict = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Updates a group resource.

    Args:
        group_name(str, optional): The case-sensitive name of the group. Defaults to None.
        group_arn(str, optional): The ARN that was generated upon creation. Defaults to None.
        filter_expression(str, optional): The updated filter expression defining criteria by which to group traces. Defaults to None.
        insights_configuration(Dict, optional): The structure containing configurations related to insights.   The InsightsEnabled boolean can be set to true to enable insights for the group or false to disable insights for the group.   The NotifcationsEnabled boolean can be set to true to enable insights notifications for the group. Notifications can only be enabled on a group with InsightsEnabled set to true.  . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.xray.group.update(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.xray.group.update
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="xray",
        operation="update_group",
        op_kwargs={
            "GroupName": group_name,
            "GroupARN": group_arn,
            "FilterExpression": filter_expression,
            "InsightsConfiguration": insights_configuration,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def cancel(hub, ctx, domain_name: str) -> Dict:
    r"""
    **Autogenerated function**

    Cancels a scheduled service software update for an Amazon ES domain. You can only perform this operation before the AutomatedUpdateDate and when the UpdateStatus is in the PENDING_UPDATE state.

    Args:
        domain_name(str): The name of the domain that you want to stop the latest service software update on.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.es.elasticsearch.service.software_update.cancel(
                ctx, domain_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.es.elasticsearch.service.software_update.cancel domain_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="es",
        operation="cancel_elasticsearch_service_software_update",
        op_kwargs={"DomainName": domain_name},
    )


async def start(hub, ctx, domain_name: str) -> Dict:
    r"""
    **Autogenerated function**

    Schedules a service software update for an Amazon ES domain.

    Args:
        domain_name(str): The name of the domain that you want to update to the latest service software.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.es.elasticsearch.service.software_update.start(
                ctx, domain_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.es.elasticsearch.service.software_update.start domain_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="es",
        operation="start_elasticsearch_service_software_update",
        op_kwargs={"DomainName": domain_name},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def get(hub, ctx) -> Dict:
    r"""
    **Autogenerated function**

    Returns the Amazon EMR block public access configuration for your account in the current Region. For more information see Configure Block Public Access for Amazon EMR in the Amazon EMR Management Guide.


    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.emr.block_public_access_configuration.get(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.emr.block_public_access_configuration.get
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="emr",
        operation="get_block_public_access_configuration",
        op_kwargs={},
    )


async def put(hub, ctx, block_public_access_configuration: Dict) -> Dict:
    r"""
    **Autogenerated function**

    Creates or updates an Amazon EMR block public access configuration for your account in the current Region. For more information see Configure Block Public Access for Amazon EMR in the Amazon EMR Management Guide.

    Args:
        block_public_access_configuration(Dict): A configuration for Amazon EMR block public access. The configuration applies to all clusters created in your account for the current Region. The configuration specifies whether block public access is enabled. If block public access is enabled, security groups associated with the cluster cannot have rules that allow inbound traffic from 0.0.0.0/0 or ::/0 on a port, unless the port is specified as an exception using PermittedPublicSecurityGroupRuleRanges in the BlockPublicAccessConfiguration. By default, Port 22 (SSH) is an exception, and public access is allowed on this port. You can change this by updating BlockPublicSecurityGroupRules to remove the exception.  For accounts that created clusters in a Region before November 25, 2019, block public access is disabled by default in that Region. To use this feature, you must manually enable and configure it. For accounts that did not create an EMR cluster in a Region before this date, block public access is enabled by default in that Region. .

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.emr.block_public_access_configuration.put(
                ctx, block_public_access_configuration=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.emr.block_public_access_configuration.put block_public_access_configuration=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="emr",
        operation="put_block_public_access_configuration",
        op_kwargs={"BlockPublicAccessConfiguration": block_public_access_configuration},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def tag(hub, ctx, resource_arn: str, tags: Dict) -> None:
    r"""
        **Autogenerated function**

        Adds or updates the tags associated with the resource ARN. See AWS IoT 1-Click Service Limits for the maximum number of tags allowed per
         resource.

        Args:
            resource_arn(str): The ARN of the resource.
            tags(Dict): A collection of key/value pairs defining the resource tags. For example, {
     "tags": {"key1": "value1", "key2": "value2"} }. For more information, see AWS
     Tagging Strategies.
    .
        Examples:
            Call from code:

            .. code-block:: python

                await hub.exec.aws_auto.iot1click_device.resource.tag(
                    ctx, resource_arn=value, tags=value
                )

            Call from CLI:

            .. code-block:: bash

                $ idem exec aws_auto.iot1click_device.resource.tag resource_arn=value, tags=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iot1click-devices",
        operation="tag_resource",
        op_kwargs={"ResourceArn": resource_arn, "Tags": tags},
    )


async def untag(hub, ctx, resource_arn: str, tag_keys: List) -> None:
    r"""
    **Autogenerated function**

    Using tag keys, deletes the tags (key/value pairs) associated with the specified
     resource ARN.

    Args:
        resource_arn(str): The ARN of the resource.
        tag_keys(List): A collections of tag keys. For example, {"key1","key2"}.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iot1click_device.resource.untag(
                ctx, resource_arn=value, tag_keys=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iot1click_device.resource.untag resource_arn=value, tag_keys=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iot1click-devices",
        operation="untag_resource",
        op_kwargs={"ResourceArn": resource_arn, "TagKeys": tag_keys},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def cancel(hub, ctx, job_id: str, api_version: str = None) -> Dict:
    r"""
    **Autogenerated function**

    This operation cancels a specified job. Only the job owner can cancel it. The operation fails if the job has already started or is complete.

    Args:
        job_id(str): A unique identifier which refers to a particular job.
        api_version(str, optional): Specifies the version of the client tool. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.importexport.job.cancel(ctx, job_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.importexport.job.cancel job_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="importexport",
        operation="cancel_job",
        op_kwargs={"JobId": job_id, "APIVersion": api_version},
    )


async def create(
    hub,
    ctx,
    job_type: str,
    manifest: str,
    validate_only: bool,
    manifest_addendum: str = None,
    api_version: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    This operation initiates the process of scheduling an upload or download of your data. You include in the request a manifest that describes the data transfer specifics. The response to the request includes a job ID, which you can use in other operations, a signature that you use to identify your storage device, and the address where you should ship your storage device.

    Args:
        job_type(str): Specifies whether the job to initiate is an import or export job.
        manifest(str): The UTF-8 encoded text of the manifest file.
        manifest_addendum(str, optional): For internal use only. Defaults to None.
        validate_only(bool): Validate the manifest and parameter values in the request but do not actually create a job.
        api_version(str, optional): Specifies the version of the client tool. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.importexport.job.create(
                ctx, job_type=value, manifest=value, validate_only=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.importexport.job.create job_type=value, manifest=value, validate_only=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="importexport",
        operation="create_job",
        op_kwargs={
            "JobType": job_type,
            "Manifest": manifest,
            "ManifestAddendum": manifest_addendum,
            "ValidateOnly": validate_only,
            "APIVersion": api_version,
        },
    )


async def update(
    hub,
    ctx,
    job_id: str,
    manifest: str,
    job_type: str,
    validate_only: bool,
    api_version: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    You use this operation to change the parameters specified in the original manifest file by supplying a new manifest file. The manifest file attached to this request replaces the original manifest file. You can only use the operation after a CreateJob request but before the data transfer starts and you can only use it on jobs you own.

    Args:
        job_id(str): A unique identifier which refers to a particular job.
        manifest(str): The UTF-8 encoded text of the manifest file.
        job_type(str): Specifies whether the job to initiate is an import or export job.
        validate_only(bool): Validate the manifest and parameter values in the request but do not actually create a job.
        api_version(str, optional): Specifies the version of the client tool. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.importexport.job.update(
                ctx, job_id=value, manifest=value, job_type=value, validate_only=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.importexport.job.update job_id=value, manifest=value, job_type=value, validate_only=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="importexport",
        operation="update_job",
        op_kwargs={
            "JobId": job_id,
            "Manifest": manifest,
            "JobType": job_type,
            "ValidateOnly": validate_only,
            "APIVersion": api_version,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def detach(hub, ctx, load_balancer_name: str, instance_names: List) -> Dict:
    r"""
    **Autogenerated function**

    Detaches the specified instances from a Lightsail load balancer. This operation waits until the instances are no longer needed before they are detached from the load balancer. The detach instances from load balancer operation supports tag-based access control via resource tags applied to the resource identified by load balancer name. For more information, see the Amazon Lightsail Developer Guide.

    Args:
        load_balancer_name(str): The name of the Lightsail load balancer.
        instance_names(List): An array of strings containing the names of the instances you want to detach from the load balancer.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.lightsail.instance.from_.load_balancer.detach(
                ctx, load_balancer_name=value, instance_names=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.lightsail.instance.from_.load_balancer.detach load_balancer_name=value, instance_names=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="lightsail",
        operation="detach_instances_from_load_balancer",
        op_kwargs={
            "loadBalancerName": load_balancer_name,
            "instanceNames": instance_names,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


__func_alias__ = {"list_": "list"}


async def list_(
    hub,
    ctx,
    accept_language: str = None,
    access_level_filter: Dict = None,
    search_filter: Dict = None,
    page_size: int = None,
    page_token: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Lists the specified requests or all performed requests.

    Args:
        accept_language(str, optional): The language code.    en - English (default)    jp - Japanese    zh - Chinese  . Defaults to None.
        access_level_filter(Dict, optional): The access level to use to obtain results. The default is User. Defaults to None.
        search_filter(Dict, optional): The search filter to scope the results. Defaults to None.
        page_size(int, optional): The maximum number of items to return with this call. Defaults to None.
        page_token(str, optional): The page token for the next set of results. To retrieve the first set of results, use null. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.servicecatalog.record.history.list(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.servicecatalog.record.history.list
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="servicecatalog",
        operation="list_record_history",
        op_kwargs={
            "AcceptLanguage": accept_language,
            "AccessLevelFilter": access_level_filter,
            "SearchFilter": search_filter,
            "PageSize": page_size,
            "PageToken": page_token,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub,
    ctx,
    profile_name: str,
    timezone: str,
    address: str,
    distance_unit: str,
    temperature_unit: str,
    wake_word: str,
    locale: str = None,
    client_request_token: str = None,
    setup_mode_disabled: bool = None,
    max_volume_limit: int = None,
    pstn_enabled: bool = None,
    data_retention_opt_in: bool = None,
    meeting_room_configuration: Dict = None,
    tags: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a new room profile with the specified details.

    Args:
        profile_name(str): The name of a room profile.
        timezone(str): The time zone used by a room profile.
        address(str): The valid address for the room.
        distance_unit(str): The distance unit to be used by devices in the profile.
        temperature_unit(str): The temperature unit to be used by devices in the profile.
        wake_word(str): A wake word for Alexa, Echo, Amazon, or a computer.
        locale(str, optional): The locale of the room profile. (This is currently only available to a limited preview audience.). Defaults to None.
        client_request_token(str, optional): The user-specified token that is used during the creation of a profile. Defaults to None.
        setup_mode_disabled(bool, optional): Whether room profile setup is enabled. Defaults to None.
        max_volume_limit(int, optional): The maximum volume limit for a room profile. Defaults to None.
        pstn_enabled(bool, optional): Whether PSTN calling is enabled. Defaults to None.
        data_retention_opt_in(bool, optional): Whether data retention of the profile is enabled. Defaults to None.
        meeting_room_configuration(Dict, optional): The meeting room settings of a room profile. Defaults to None.
        tags(List, optional): The tags for the profile. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.alexaforbusiness.profile.create(
                ctx,
                profile_name=value,
                timezone=value,
                address=value,
                distance_unit=value,
                temperature_unit=value,
                wake_word=value,
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.alexaforbusiness.profile.create profile_name=value, timezone=value, address=value, distance_unit=value, temperature_unit=value, wake_word=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="alexaforbusiness",
        operation="create_profile",
        op_kwargs={
            "ProfileName": profile_name,
            "Timezone": timezone,
            "Address": address,
            "DistanceUnit": distance_unit,
            "TemperatureUnit": temperature_unit,
            "WakeWord": wake_word,
            "Locale": locale,
            "ClientRequestToken": client_request_token,
            "SetupModeDisabled": setup_mode_disabled,
            "MaxVolumeLimit": max_volume_limit,
            "PSTNEnabled": pstn_enabled,
            "DataRetentionOptIn": data_retention_opt_in,
            "MeetingRoomConfiguration": meeting_room_configuration,
            "Tags": tags,
        },
    )


async def delete(hub, ctx, profile_arn: str = None) -> Dict:
    r"""
    **Autogenerated function**

    Deletes a room profile by the profile ARN.

    Args:
        profile_arn(str, optional): The ARN of the room profile to delete. Required. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.alexaforbusiness.profile.delete(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.alexaforbusiness.profile.delete
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="alexaforbusiness",
        operation="delete_profile",
        op_kwargs={"ProfileArn": profile_arn},
    )


async def get(hub, ctx, profile_arn: str = None) -> Dict:
    r"""
    **Autogenerated function**

    Gets the details of a room profile by profile ARN.

    Args:
        profile_arn(str, optional): The ARN of the room profile for which to request details. Required. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.alexaforbusiness.profile.get(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.alexaforbusiness.profile.get
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="alexaforbusiness",
        operation="get_profile",
        op_kwargs={"ProfileArn": profile_arn},
    )


async def search(
    hub,
    ctx,
    next_token: str = None,
    max_results: int = None,
    filters: List = None,
    sort_criteria: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Searches room profiles and lists the ones that meet a set of filter criteria.

    Args:
        next_token(str, optional): An optional token returned from a prior request. Use this token for pagination of results from this action. If this parameter is specified, the response includes only results beyond the token, up to the value specified by MaxResults. Defaults to None.
        max_results(int, optional): The maximum number of results to include in the response. If more results exist than the specified MaxResults value, a token is included in the response so that the remaining results can be retrieved. Defaults to None.
        filters(List, optional): The filters to use to list a specified set of room profiles. Supported filter keys are ProfileName and Address. Required. . Defaults to None.
        sort_criteria(List, optional): The sort order to use in listing the specified set of room profiles. Supported sort keys are ProfileName and Address. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.alexaforbusiness.profile.search(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.alexaforbusiness.profile.search
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="alexaforbusiness",
        operation="search_profiles",
        op_kwargs={
            "NextToken": next_token,
            "MaxResults": max_results,
            "Filters": filters,
            "SortCriteria": sort_criteria,
        },
    )


async def update(
    hub,
    ctx,
    profile_arn: str = None,
    profile_name: str = None,
    is_default: bool = None,
    timezone: str = None,
    address: str = None,
    distance_unit: str = None,
    temperature_unit: str = None,
    wake_word: str = None,
    locale: str = None,
    setup_mode_disabled: bool = None,
    max_volume_limit: int = None,
    pstn_enabled: bool = None,
    data_retention_opt_in: bool = None,
    meeting_room_configuration: Dict = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Updates an existing room profile by room profile ARN.

    Args:
        profile_arn(str, optional): The ARN of the room profile to update. Required. Defaults to None.
        profile_name(str, optional): The updated name for the room profile. Defaults to None.
        is_default(bool, optional): Sets the profile as default if selected. If this is missing, no update is done to the default status. Defaults to None.
        timezone(str, optional): The updated timezone for the room profile. Defaults to None.
        address(str, optional): The updated address for the room profile. Defaults to None.
        distance_unit(str, optional): The updated distance unit for the room profile. Defaults to None.
        temperature_unit(str, optional): The updated temperature unit for the room profile. Defaults to None.
        wake_word(str, optional): The updated wake word for the room profile. Defaults to None.
        locale(str, optional): The updated locale for the room profile. (This is currently only available to a limited preview audience.). Defaults to None.
        setup_mode_disabled(bool, optional): Whether the setup mode of the profile is enabled. Defaults to None.
        max_volume_limit(int, optional): The updated maximum volume limit for the room profile. Defaults to None.
        pstn_enabled(bool, optional): Whether the PSTN setting of the room profile is enabled. Defaults to None.
        data_retention_opt_in(bool, optional): Whether data retention of the profile is enabled. Defaults to None.
        meeting_room_configuration(Dict, optional): The updated meeting room settings of a room profile. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.alexaforbusiness.profile.update(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.alexaforbusiness.profile.update
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="alexaforbusiness",
        operation="update_profile",
        op_kwargs={
            "ProfileArn": profile_arn,
            "ProfileName": profile_name,
            "IsDefault": is_default,
            "Timezone": timezone,
            "Address": address,
            "DistanceUnit": distance_unit,
            "TemperatureUnit": temperature_unit,
            "WakeWord": wake_word,
            "Locale": locale,
            "SetupModeDisabled": setup_mode_disabled,
            "MaxVolumeLimit": max_volume_limit,
            "PSTNEnabled": pstn_enabled,
            "DataRetentionOptIn": data_retention_opt_in,
            "MeetingRoomConfiguration": meeting_room_configuration,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub,
    ctx,
    auto_ml_job_name: str,
    input_data_config: List,
    output_data_config: Dict,
    role_arn: str,
    problem_type: str = None,
    auto_ml_job_objective: Dict = None,
    auto_ml_job_config: Dict = None,
    generate_candidate_definitions_only: bool = None,
    tags: List = None,
    model_deploy_config: Dict = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates an Autopilot job. Find the best performing model after you run an Autopilot job by calling . For information about how to use Autopilot, see Automate Model Development with Amazon SageMaker Autopilot.

    Args:
        auto_ml_job_name(str): Identifies an Autopilot job. The name must be unique to your account and is case-insensitive.
        input_data_config(List): An array of channel objects that describes the input data and its location. Each channel is a named input source. Similar to InputDataConfig supported by . Format(s) supported: CSV. Minimum of 500 rows.
        output_data_config(Dict): Provides information about encryption and the Amazon S3 output path needed to store artifacts from an AutoML job. Format(s) supported: CSV.
        problem_type(str, optional): Defines the type of supervised learning available for the candidates. Options include: BinaryClassification, MulticlassClassification, and Regression. For more information, see  Amazon SageMaker Autopilot problem types and algorithm support. Defaults to None.
        auto_ml_job_objective(Dict, optional): Defines the objective metric used to measure the predictive quality of an AutoML job. You provide an AutoMLJobObjective$MetricName and Autopilot infers whether to minimize or maximize it. Defaults to None.
        auto_ml_job_config(Dict, optional): Contains CompletionCriteria and SecurityConfig settings for the AutoML job. Defaults to None.
        role_arn(str): The ARN of the role that is used to access the data.
        generate_candidate_definitions_only(bool, optional): Generates possible candidates without training the models. A candidate is a combination of data preprocessors, algorithms, and algorithm parameter settings. Defaults to None.
        tags(List, optional): Each tag consists of a key and an optional value. Tag keys must be unique per resource. Defaults to None.
        model_deploy_config(Dict, optional): Specifies how to generate the endpoint name for an automatic one-click Autopilot model deployment. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.sagemaker.auto_ml_job.create(
                ctx,
                auto_ml_job_name=value,
                input_data_config=value,
                output_data_config=value,
                role_arn=value,
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.sagemaker.auto_ml_job.create auto_ml_job_name=value, input_data_config=value, output_data_config=value, role_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="sagemaker",
        operation="create_auto_ml_job",
        op_kwargs={
            "AutoMLJobName": auto_ml_job_name,
            "InputDataConfig": input_data_config,
            "OutputDataConfig": output_data_config,
            "ProblemType": problem_type,
            "AutoMLJobObjective": auto_ml_job_objective,
            "AutoMLJobConfig": auto_ml_job_config,
            "RoleArn": role_arn,
            "GenerateCandidateDefinitionsOnly": generate_candidate_definitions_only,
            "Tags": tags,
            "ModelDeployConfig": model_deploy_config,
        },
    )


async def describe(hub, ctx, auto_ml_job_name: str) -> Dict:
    r"""
    **Autogenerated function**

    Returns information about an Amazon SageMaker AutoML job.

    Args:
        auto_ml_job_name(str): Requests information about an AutoML job using its unique name.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.sagemaker.auto_ml_job.describe(ctx, auto_ml_job_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.sagemaker.auto_ml_job.describe auto_ml_job_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="sagemaker",
        operation="describe_auto_ml_job",
        op_kwargs={"AutoMLJobName": auto_ml_job_name},
    )


async def list_all(
    hub,
    ctx,
    creation_time_after: str = None,
    creation_time_before: str = None,
    last_modified_time_after: str = None,
    last_modified_time_before: str = None,
    name_contains: str = None,
    status_equals: str = None,
    sort_order: str = None,
    sort_by: str = None,
    max_results: int = None,
    next_token: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Request a list of jobs.

    Args:
        creation_time_after(str, optional): Request a list of jobs, using a filter for time. Defaults to None.
        creation_time_before(str, optional): Request a list of jobs, using a filter for time. Defaults to None.
        last_modified_time_after(str, optional): Request a list of jobs, using a filter for time. Defaults to None.
        last_modified_time_before(str, optional): Request a list of jobs, using a filter for time. Defaults to None.
        name_contains(str, optional): Request a list of jobs, using a search filter for name. Defaults to None.
        status_equals(str, optional): Request a list of jobs, using a filter for status. Defaults to None.
        sort_order(str, optional): The sort order for the results. The default is Descending. Defaults to None.
        sort_by(str, optional): The parameter by which to sort the results. The default is Name. Defaults to None.
        max_results(int, optional): Request a list of jobs up to a specified limit. Defaults to None.
        next_token(str, optional): If the previous response was truncated, you receive this token. Use it in your next request to receive the next set of results. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.sagemaker.auto_ml_job.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.sagemaker.auto_ml_job.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="sagemaker",
        operation="list_auto_ml_jobs",
        op_kwargs={
            "CreationTimeAfter": creation_time_after,
            "CreationTimeBefore": creation_time_before,
            "LastModifiedTimeAfter": last_modified_time_after,
            "LastModifiedTimeBefore": last_modified_time_before,
            "NameContains": name_contains,
            "StatusEquals": status_equals,
            "SortOrder": sort_order,
            "SortBy": sort_by,
            "MaxResults": max_results,
            "NextToken": next_token,
        },
    )


async def stop(hub, ctx, auto_ml_job_name: str) -> None:
    r"""
    **Autogenerated function**

    A method for forcing the termination of a running job.

    Args:
        auto_ml_job_name(str): The name of the object you are requesting.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.sagemaker.auto_ml_job.stop(ctx, auto_ml_job_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.sagemaker.auto_ml_job.stop auto_ml_job_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="sagemaker",
        operation="stop_auto_ml_job",
        op_kwargs={"AutoMLJobName": auto_ml_job_name},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


__func_alias__ = {"list_": "list"}


async def list_(hub, ctx, resource_name: str, next_token: str = None) -> Dict:
    r"""
    **Autogenerated function**

    List all of the tags for a DAX cluster. You can call ListTags up to 10 times per second, per account.

    Args:
        resource_name(str): The name of the DAX resource to which the tags belong.
        next_token(str, optional): An optional token returned from a prior request. Use this token for pagination of results from this action. If this parameter is specified, the response includes only results beyond the token. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.dax.tags.list(ctx, resource_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.dax.tags.list resource_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="dax",
        operation="list_tags",
        op_kwargs={"ResourceName": resource_name, "NextToken": next_token},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def describe_all(
    hub,
    ctx,
    case_id: str,
    before_time: str = None,
    after_time: str = None,
    next_token: str = None,
    max_results: int = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Returns communications and attachments for one or more support cases. Use the afterTime and beforeTime parameters to filter by date. You can use the caseId parameter to restrict the results to a specific case. Case data is available for 12 months after creation. If a case was created more than 12 months ago, a request for data might cause an error. You can use the maxResults and nextToken parameters to control the pagination of the results. Set maxResults to the number of cases that you want to display on each page, and use nextToken to specify the resumption of pagination.    You must have a Business or Enterprise Support plan to use the AWS Support API.    If you call the AWS Support API from an account that does not have a Business or Enterprise Support plan, the SubscriptionRequiredException error message appears. For information about changing your support plan, see AWS Support.

    Args:
        case_id(str): The support case ID requested or returned in the call. The case ID is an alphanumeric string formatted as shown in this example: case-12345678910-2013-c4c1d2bf33c5cf47 .
        before_time(str, optional): The end date for a filtered date search on support case communications. Case communications are available for 12 months after creation. Defaults to None.
        after_time(str, optional): The start date for a filtered date search on support case communications. Case communications are available for 12 months after creation. Defaults to None.
        next_token(str, optional): A resumption point for pagination. Defaults to None.
        max_results(int, optional): The maximum number of results to return before paginating. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.support.communication.init.describe_all(ctx, case_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.support.communication.init.describe_all case_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="support",
        operation="describe_communications",
        op_kwargs={
            "caseId": case_id,
            "beforeTime": before_time,
            "afterTime": after_time,
            "nextToken": next_token,
            "maxResults": max_results,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def get_all(
    hub,
    ctx,
    namespace: str,
    metric_name: str,
    start_time: str,
    end_time: str,
    period: int,
    dimensions: List = None,
    statistics: List = None,
    extended_statistics: List = None,
    unit: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Gets statistics for the specified metric. The maximum number of data points returned from a single call is 1,440. If you request more than 1,440 data points, CloudWatch returns an error. To reduce the number of data points, you can narrow the specified time range and make multiple requests across adjacent time ranges, or you can increase the specified period. Data points are not returned in chronological order. CloudWatch aggregates data points based on the length of the period that you specify. For example, if you request statistics with a one-hour period, CloudWatch aggregates all data points with time stamps that fall within each one-hour period. Therefore, the number of values aggregated by CloudWatch is larger than the number of data points returned. CloudWatch needs raw data points to calculate percentile statistics. If you publish data using a statistic set instead, you can only retrieve percentile statistics for this data if one of the following conditions is true:   The SampleCount value of the statistic set is 1.   The Min and the Max values of the statistic set are equal.   Percentile statistics are not available for metrics when any of the metric values are negative numbers. Amazon CloudWatch retains metric data as follows:   Data points with a period of less than 60 seconds are available for 3 hours. These data points are high-resolution metrics and are available only for custom metrics that have been defined with a StorageResolution of 1.   Data points with a period of 60 seconds (1-minute) are available for 15 days.   Data points with a period of 300 seconds (5-minute) are available for 63 days.   Data points with a period of 3600 seconds (1 hour) are available for 455 days (15 months).   Data points that are initially published with a shorter period are aggregated together for long-term storage. For example, if you collect data using a period of 1 minute, the data remains available for 15 days with 1-minute resolution. After 15 days, this data is still available, but is aggregated and retrievable only with a resolution of 5 minutes. After 63 days, the data is further aggregated and is available with a resolution of 1 hour. CloudWatch started retaining 5-minute and 1-hour metric data as of July 9, 2016. For information about metrics and dimensions supported by Amazon Web Services services, see the Amazon CloudWatch Metrics and Dimensions Reference in the Amazon CloudWatch User Guide.

    Args:
        namespace(str): The namespace of the metric, with or without spaces.
        metric_name(str): The name of the metric, with or without spaces.
        dimensions(List, optional): The dimensions. If the metric contains multiple dimensions, you must include a value for each dimension. CloudWatch treats each unique combination of dimensions as a separate metric. If a specific combination of dimensions was not published, you can't retrieve statistics for it. You must specify the same dimensions that were used when the metrics were created. For an example, see Dimension Combinations in the Amazon CloudWatch User Guide. For more information about specifying dimensions, see Publishing Metrics in the Amazon CloudWatch User Guide. Defaults to None.
        start_time(str): The time stamp that determines the first data point to return. Start times are evaluated relative to the time that CloudWatch receives the request. The value specified is inclusive; results include data points with the specified time stamp. In a raw HTTP query, the time stamp must be in ISO 8601 UTC format (for example, 2016-10-03T23:00:00Z). CloudWatch rounds the specified time stamp as follows:   Start time less than 15 days ago - Round down to the nearest whole minute. For example, 12:32:34 is rounded down to 12:32:00.   Start time between 15 and 63 days ago - Round down to the nearest 5-minute clock interval. For example, 12:32:34 is rounded down to 12:30:00.   Start time greater than 63 days ago - Round down to the nearest 1-hour clock interval. For example, 12:32:34 is rounded down to 12:00:00.   If you set Period to 5, 10, or 30, the start time of your request is rounded down to the nearest time that corresponds to even 5-, 10-, or 30-second divisions of a minute. For example, if you make a query at (HH:mm:ss) 01:05:23 for the previous 10-second period, the start time of your request is rounded down and you receive data from 01:05:10 to 01:05:20. If you make a query at 15:07:17 for the previous 5 minutes of data, using a period of 5 seconds, you receive data timestamped between 15:02:15 and 15:07:15. .
        end_time(str): The time stamp that determines the last data point to return. The value specified is exclusive; results include data points up to the specified time stamp. In a raw HTTP query, the time stamp must be in ISO 8601 UTC format (for example, 2016-10-10T23:00:00Z).
        period(int): The granularity, in seconds, of the returned data points. For metrics with regular resolution, a period can be as short as one minute (60 seconds) and must be a multiple of 60. For high-resolution metrics that are collected at intervals of less than one minute, the period can be 1, 5, 10, 30, 60, or any multiple of 60. High-resolution metrics are those metrics stored by a PutMetricData call that includes a StorageResolution of 1 second. If the StartTime parameter specifies a time stamp that is greater than 3 hours ago, you must specify the period as follows or no data points in that time range is returned:   Start time between 3 hours and 15 days ago - Use a multiple of 60 seconds (1 minute).   Start time between 15 and 63 days ago - Use a multiple of 300 seconds (5 minutes).   Start time greater than 63 days ago - Use a multiple of 3600 seconds (1 hour).  .
        statistics(List, optional): The metric statistics, other than percentile. For percentile statistics, use ExtendedStatistics. When calling GetMetricStatistics, you must specify either Statistics or ExtendedStatistics, but not both. Defaults to None.
        extended_statistics(List, optional): The percentile statistics. Specify values between p0.0 and p100. When calling GetMetricStatistics, you must specify either Statistics or ExtendedStatistics, but not both. Percentile statistics are not available for metrics when any of the metric values are negative numbers. Defaults to None.
        unit(str, optional): The unit for a given metric. If you omit Unit, all data that was collected with any unit is returned, along with the corresponding units that were specified when the data was reported to CloudWatch. If you specify a unit, the operation returns only data that was collected with that unit specified. If you specify a unit that does not match the data collected, the results of the operation are null. CloudWatch does not perform unit conversions. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.cloudwatch.metric.statistic.get_all(
                ctx,
                namespace=value,
                metric_name=value,
                start_time=value,
                end_time=value,
                period=value,
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.cloudwatch.metric.statistic.get_all namespace=value, metric_name=value, start_time=value, end_time=value, period=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="cloudwatch",
        operation="get_metric_statistics",
        op_kwargs={
            "Namespace": namespace,
            "MetricName": metric_name,
            "Dimensions": dimensions,
            "StartTime": start_time,
            "EndTime": end_time,
            "Period": period,
            "Statistics": statistics,
            "ExtendedStatistics": extended_statistics,
            "Unit": unit,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def get(
    hub,
    ctx,
    bucket: str,
    key: str,
    version_id: str = None,
    request_payer: str = None,
    expected_bucket_owner: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Retrieves an object's retention settings. For more information, see Locking Objects. This action is not supported by Amazon S3 on Outposts.

    Args:
        bucket(str): The bucket name containing the object whose retention settings you want to retrieve.  When using this action with an access point, you must direct requests to the access point hostname. The access point hostname takes the form AccessPointName-AccountId.s3-accesspoint.Region.amazonaws.com. When using this action with an access point through the AWS SDKs, you provide the access point ARN in place of the bucket name. For more information about access point ARNs, see Using access points in the Amazon S3 User Guide.
        key(str): The key name for the object whose retention settings you want to retrieve.
        version_id(str, optional): The version ID for the object whose retention settings you want to retrieve. Defaults to None.
        request_payer(str, optional): Confirms that the requester knows that they will be charged for the request. Bucket owners need not specify this parameter in their requests. For information about downloading objects from requester pays buckets, see Downloading Objects in Requestor Pays Buckets in the Amazon S3 User Guide. Defaults to None.
        expected_bucket_owner(str, optional): The account ID of the expected bucket owner. If the bucket is owned by a different account, the request will fail with an HTTP 403 (Access Denied) error. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.s3.object_.retention.get(ctx, bucket=value, key=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.s3.object_.retention.get bucket=value, key=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="s3",
        operation="get_object_retention",
        op_kwargs={
            "Bucket": bucket,
            "Key": key,
            "VersionId": version_id,
            "RequestPayer": request_payer,
            "ExpectedBucketOwner": expected_bucket_owner,
        },
    )


async def put(
    hub,
    ctx,
    bucket: str,
    key: str,
    retention: Dict = None,
    request_payer: str = None,
    version_id: str = None,
    bypass_governance_retention: bool = None,
    content_md5: str = None,
    expected_bucket_owner: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Places an Object Retention configuration on an object. For more information, see Locking Objects.  This action is not supported by Amazon S3 on Outposts.

    Args:
        bucket(str): The bucket name that contains the object you want to apply this Object Retention configuration to.  When using this action with an access point, you must direct requests to the access point hostname. The access point hostname takes the form AccessPointName-AccountId.s3-accesspoint.Region.amazonaws.com. When using this action with an access point through the AWS SDKs, you provide the access point ARN in place of the bucket name. For more information about access point ARNs, see Using access points in the Amazon S3 User Guide.
        key(str): The key name for the object that you want to apply this Object Retention configuration to.
        retention(Dict, optional): The container element for the Object Retention configuration. Defaults to None.
        request_payer(str, optional): Confirms that the requester knows that they will be charged for the request. Bucket owners need not specify this parameter in their requests. For information about downloading objects from requester pays buckets, see Downloading Objects in Requestor Pays Buckets in the Amazon S3 User Guide. Defaults to None.
        version_id(str, optional): The version ID for the object that you want to apply this Object Retention configuration to. Defaults to None.
        bypass_governance_retention(bool, optional): Indicates whether this action should bypass Governance-mode restrictions. Defaults to None.
        content_md5(str, optional): The MD5 hash for the request body. For requests made using the AWS Command Line Interface (CLI) or AWS SDKs, this field is calculated automatically. Defaults to None.
        expected_bucket_owner(str, optional): The account ID of the expected bucket owner. If the bucket is owned by a different account, the request will fail with an HTTP 403 (Access Denied) error. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.s3.object_.retention.put(ctx, bucket=value, key=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.s3.object_.retention.put bucket=value, key=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="s3",
        operation="put_object_retention",
        op_kwargs={
            "Bucket": bucket,
            "Key": key,
            "Retention": retention,
            "RequestPayer": request_payer,
            "VersionId": version_id,
            "BypassGovernanceRetention": bypass_governance_retention,
            "ContentMD5": content_md5,
            "ExpectedBucketOwner": expected_bucket_owner,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def get_all(hub, ctx, cluster_arn: str) -> Dict:
    r"""
        **Autogenerated function**


        A list of brokers that a client application can use to bootstrap.


        Args:
            cluster_arn(str):
    The Amazon Resource Name (ARN) that uniquely identifies the cluster.
    .

        Returns:
            Dict

        Examples:
            Call from code:

            .. code-block:: python

                await hub.exec.aws_auto.kafka.bootstrap_broker.get_all(ctx, cluster_arn=value)

            Call from CLI:

            .. code-block:: bash

                $ idem exec aws_auto.kafka.bootstrap_broker.get_all cluster_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="kafka",
        operation="get_bootstrap_brokers",
        op_kwargs={"ClusterArn": cluster_arn},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def update(hub, ctx, hit_id: str, hit_type_id: str) -> Dict:
    r"""
    **Autogenerated function**

     The UpdateHITTypeOfHIT operation allows you to change the HITType properties of a HIT. This operation disassociates the HIT from its old HITType properties and associates it with the new HITType properties. The HIT takes on the properties of the new HITType in place of the old ones.

    Args:
        hit_id(str): The HIT to update.
        hit_type_id(str): The ID of the new HIT type.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.mturk.hit.type_.of_hit.update(
                ctx, hit_id=value, hit_type_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.mturk.hit.type_.of_hit.update hit_id=value, hit_type_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="mturk",
        operation="update_hit_type_of_hit",
        op_kwargs={"HITId": hit_id, "HITTypeId": hit_type_id},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(hub, ctx, schema_arn: str, facet: Dict) -> Dict:
    r"""
    **Autogenerated function**

    Creates a TypedLinkFacet. For more information, see Typed Links.

    Args:
        schema_arn(str): The Amazon Resource Name (ARN) that is associated with the schema. For more information, see arns.
        facet(Dict):  Facet structure that is associated with the typed link facet.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.clouddirectory.typed_link.facet.init.create(
                ctx, schema_arn=value, facet=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.clouddirectory.typed_link.facet.init.create schema_arn=value, facet=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="clouddirectory",
        operation="create_typed_link_facet",
        op_kwargs={"SchemaArn": schema_arn, "Facet": facet},
    )


async def delete(hub, ctx, schema_arn: str, name: str) -> Dict:
    r"""
    **Autogenerated function**

    Deletes a TypedLinkFacet. For more information, see Typed Links.

    Args:
        schema_arn(str): The Amazon Resource Name (ARN) that is associated with the schema. For more information, see arns.
        name(str): The unique name of the typed link facet.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.clouddirectory.typed_link.facet.init.delete(
                ctx, schema_arn=value, name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.clouddirectory.typed_link.facet.init.delete schema_arn=value, name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="clouddirectory",
        operation="delete_typed_link_facet",
        op_kwargs={"SchemaArn": schema_arn, "Name": name},
    )


async def update(
    hub,
    ctx,
    schema_arn: str,
    name: str,
    attribute_updates: List,
    identity_attribute_order: List,
) -> Dict:
    r"""
    **Autogenerated function**

    Updates a TypedLinkFacet. For more information, see Typed Links.

    Args:
        schema_arn(str): The Amazon Resource Name (ARN) that is associated with the schema. For more information, see arns.
        name(str): The unique name of the typed link facet.
        attribute_updates(List): Attributes update structure.
        identity_attribute_order(List): The order of identity attributes for the facet, from most significant to least significant. The ability to filter typed links considers the order that the attributes are defined on the typed link facet. When providing ranges to a typed link selection, any inexact ranges must be specified at the end. Any attributes that do not have a range specified are presumed to match the entire range. Filters are interpreted in the order of the attributes on the typed link facet, not the order in which they are supplied to any API calls. For more information about identity attributes, see Typed Links.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.clouddirectory.typed_link.facet.init.update(
                ctx,
                schema_arn=value,
                name=value,
                attribute_updates=value,
                identity_attribute_order=value,
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.clouddirectory.typed_link.facet.init.update schema_arn=value, name=value, attribute_updates=value, identity_attribute_order=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="clouddirectory",
        operation="update_typed_link_facet",
        op_kwargs={
            "SchemaArn": schema_arn,
            "Name": name,
            "AttributeUpdates": attribute_updates,
            "IdentityAttributeOrder": identity_attribute_order,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def describe_all(hub, ctx) -> Dict:
    r"""
    **Autogenerated function**

    Describes the global settings of the AWS account, including whether it is opted in to cross-account backup.


    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.backup.global_setting.describe_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.backup.global_setting.describe_all
    """
    return await hub.tool.aws.client.exec(
        ctx, service_name="backup", operation="describe_global_settings", op_kwargs={}
    )


async def update_multiple(hub, ctx, global_settings: Dict = None) -> None:
    r"""
    **Autogenerated function**

    Updates the current global settings for the AWS account. Use the DescribeGlobalSettings API to determine the current settings.

    Args:
        global_settings(Dict, optional): A list of resources along with the opt-in preferences for the account. Defaults to None.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.backup.global_setting.update_multiple(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.backup.global_setting.update_multiple
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="backup",
        operation="update_global_settings",
        op_kwargs={"GlobalSettings": global_settings},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def get(hub, ctx, domain_name: str) -> Dict:
    r"""
    **Autogenerated function**

    Retrieves the latest status of the last upgrade or upgrade eligibility check that was performed on the domain.

    Args:
        domain_name(str): The name of an Elasticsearch domain. Domain names are unique across the domains owned by an account within an AWS region. Domain names start with a letter or number and can contain the following characters: a-z (lowercase), 0-9, and - (hyphen).

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.es.upgrade.status.get(ctx, domain_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.es.upgrade.status.get domain_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="es",
        operation="get_upgrade_status",
        op_kwargs={"DomainName": domain_name},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def modify(
    hub,
    ctx,
    cluster_identifier: str,
    defer_maintenance: bool = None,
    defer_maintenance_identifier: str = None,
    defer_maintenance_start_time: str = None,
    defer_maintenance_end_time: str = None,
    defer_maintenance_duration: int = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Modifies the maintenance settings of a cluster.

    Args:
        cluster_identifier(str): A unique identifier for the cluster.
        defer_maintenance(bool, optional): A boolean indicating whether to enable the deferred maintenance window. . Defaults to None.
        defer_maintenance_identifier(str, optional): A unique identifier for the deferred maintenance window. Defaults to None.
        defer_maintenance_start_time(str, optional): A timestamp indicating the start time for the deferred maintenance window. Defaults to None.
        defer_maintenance_end_time(str, optional): A timestamp indicating end time for the deferred maintenance window. If you specify an end time, you can't specify a duration. Defaults to None.
        defer_maintenance_duration(int, optional): An integer indicating the duration of the maintenance window in days. If you specify a duration, you can't specify an end time. The duration must be 45 days or less. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.redshift.cluster.maintenance.modify(
                ctx, cluster_identifier=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.redshift.cluster.maintenance.modify cluster_identifier=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="redshift",
        operation="modify_cluster_maintenance",
        op_kwargs={
            "ClusterIdentifier": cluster_identifier,
            "DeferMaintenance": defer_maintenance,
            "DeferMaintenanceIdentifier": defer_maintenance_identifier,
            "DeferMaintenanceStartTime": defer_maintenance_start_time,
            "DeferMaintenanceEndTime": defer_maintenance_end_time,
            "DeferMaintenanceDuration": defer_maintenance_duration,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub,
    ctx,
    name: str,
    metric_name: str,
    rate_key: str,
    rate_limit: int,
    change_token: str,
    tags: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

     This is AWS WAF Classic documentation. For more information, see AWS WAF Classic in the developer guide.  For the latest version of AWS WAF, use the AWS WAFV2 API and see the AWS WAF Developer Guide. With the latest version, AWS WAF has a single set of endpoints for regional and global use.   Creates a RateBasedRule. The RateBasedRule contains a RateLimit, which specifies the maximum number of requests that AWS WAF allows from a specified IP address in a five-minute period. The RateBasedRule also contains the IPSet objects, ByteMatchSet objects, and other predicates that identify the requests that you want to count or block if these requests exceed the RateLimit. If you add more than one predicate to a RateBasedRule, a request not only must exceed the RateLimit, but it also must match all the conditions to be counted or blocked. For example, suppose you add the following to a RateBasedRule:   An IPSet that matches the IP address 192.0.2.44/32    A ByteMatchSet that matches BadBot in the User-Agent header   Further, you specify a RateLimit of 1,000. You then add the RateBasedRule to a WebACL and specify that you want to block requests that meet the conditions in the rule. For a request to be blocked, it must come from the IP address 192.0.2.44 and the User-Agent header in the request must contain the value BadBot. Further, requests that match these two conditions must be received at a rate of more than 1,000 requests every five minutes. If both conditions are met and the rate is exceeded, AWS WAF blocks the requests. If the rate drops below 1,000 for a five-minute period, AWS WAF no longer blocks the requests. As a second example, suppose you want to limit requests to a particular page on your site. To do this, you could add the following to a RateBasedRule:   A ByteMatchSet with FieldToMatch of URI    A PositionalConstraint of STARTS_WITH    A TargetString of login    Further, you specify a RateLimit of 1,000. By adding this RateBasedRule to a WebACL, you could limit requests to your login page without affecting the rest of your site. To create and configure a RateBasedRule, perform the following steps:   Create and update the predicates that you want to include in the rule. For more information, see CreateByteMatchSet, CreateIPSet, and CreateSqlInjectionMatchSet.   Use GetChangeToken to get the change token that you provide in the ChangeToken parameter of a CreateRule request.   Submit a CreateRateBasedRule request.   Use GetChangeToken to get the change token that you provide in the ChangeToken parameter of an UpdateRule request.   Submit an UpdateRateBasedRule request to specify the predicates that you want to include in the rule.   Create and update a WebACL that contains the RateBasedRule. For more information, see CreateWebACL.   For more information about how to use the AWS WAF API to allow or block HTTP requests, see the AWS WAF Developer Guide.

    Args:
        name(str): A friendly name or description of the RateBasedRule. You can't change the name of a RateBasedRule after you create it.
        metric_name(str): A friendly name or description for the metrics for this RateBasedRule. The name can contain only alphanumeric characters (A-Z, a-z, 0-9), with maximum length 128 and minimum length one. It can't contain whitespace or metric names reserved for AWS WAF, including "All" and "Default_Action." You can't change the name of the metric after you create the RateBasedRule.
        rate_key(str): The field that AWS WAF uses to determine if requests are likely arriving from a single source and thus subject to rate monitoring. The only valid value for RateKey is IP. IP indicates that requests that arrive from the same IP address are subject to the RateLimit that is specified in the RateBasedRule.
        rate_limit(int): The maximum number of requests, which have an identical value in the field that is specified by RateKey, allowed in a five-minute period. If the number of requests exceeds the RateLimit and the other predicates specified in the rule are also met, AWS WAF triggers the action that is specified for this rule.
        change_token(str): The ChangeToken that you used to submit the CreateRateBasedRule request. You can also use this value to query the status of the request. For more information, see GetChangeTokenStatus.
        tags(List, optional): . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.waf_regional.rate_based_rule.init.create(
                ctx,
                name=value,
                metric_name=value,
                rate_key=value,
                rate_limit=value,
                change_token=value,
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.waf_regional.rate_based_rule.init.create name=value, metric_name=value, rate_key=value, rate_limit=value, change_token=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="waf-regional",
        operation="create_rate_based_rule",
        op_kwargs={
            "Name": name,
            "MetricName": metric_name,
            "RateKey": rate_key,
            "RateLimit": rate_limit,
            "ChangeToken": change_token,
            "Tags": tags,
        },
    )


async def delete(hub, ctx, rule_id: str, change_token: str) -> Dict:
    r"""
    **Autogenerated function**

     This is AWS WAF Classic documentation. For more information, see AWS WAF Classic in the developer guide.  For the latest version of AWS WAF, use the AWS WAFV2 API and see the AWS WAF Developer Guide. With the latest version, AWS WAF has a single set of endpoints for regional and global use.   Permanently deletes a RateBasedRule. You can't delete a rule if it's still used in any WebACL objects or if it still includes any predicates, such as ByteMatchSet objects. If you just want to remove a rule from a WebACL, use UpdateWebACL. To permanently delete a RateBasedRule from AWS WAF, perform the following steps:   Update the RateBasedRule to remove predicates, if any. For more information, see UpdateRateBasedRule.   Use GetChangeToken to get the change token that you provide in the ChangeToken parameter of a DeleteRateBasedRule request.   Submit a DeleteRateBasedRule request.

    Args:
        rule_id(str): The RuleId of the RateBasedRule that you want to delete. RuleId is returned by CreateRateBasedRule and by ListRateBasedRules.
        change_token(str): The value returned by the most recent call to GetChangeToken.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.waf_regional.rate_based_rule.init.delete(
                ctx, rule_id=value, change_token=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.waf_regional.rate_based_rule.init.delete rule_id=value, change_token=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="waf-regional",
        operation="delete_rate_based_rule",
        op_kwargs={"RuleId": rule_id, "ChangeToken": change_token},
    )


async def get(hub, ctx, rule_id: str) -> Dict:
    r"""
    **Autogenerated function**

     This is AWS WAF Classic documentation. For more information, see AWS WAF Classic in the developer guide.  For the latest version of AWS WAF, use the AWS WAFV2 API and see the AWS WAF Developer Guide. With the latest version, AWS WAF has a single set of endpoints for regional and global use.   Returns the RateBasedRule that is specified by the RuleId that you included in the GetRateBasedRule request.

    Args:
        rule_id(str): The RuleId of the RateBasedRule that you want to get. RuleId is returned by CreateRateBasedRule and by ListRateBasedRules.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.waf_regional.rate_based_rule.init.get(ctx, rule_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.waf_regional.rate_based_rule.init.get rule_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="waf-regional",
        operation="get_rate_based_rule",
        op_kwargs={"RuleId": rule_id},
    )


async def list_all(hub, ctx, next_marker: str = None, limit: int = None) -> Dict:
    r"""
    **Autogenerated function**

     This is AWS WAF Classic documentation. For more information, see AWS WAF Classic in the developer guide.  For the latest version of AWS WAF, use the AWS WAFV2 API and see the AWS WAF Developer Guide. With the latest version, AWS WAF has a single set of endpoints for regional and global use.   Returns an array of RuleSummary objects.

    Args:
        next_marker(str, optional): If you specify a value for Limit and you have more Rules than the value of Limit, AWS WAF returns a NextMarker value in the response that allows you to list another group of Rules. For the second and subsequent ListRateBasedRules requests, specify the value of NextMarker from the previous response to get information about another batch of Rules. Defaults to None.
        limit(int, optional): Specifies the number of Rules that you want AWS WAF to return for this request. If you have more Rules than the number that you specify for Limit, the response includes a NextMarker value that you can use to get another batch of Rules. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.waf_regional.rate_based_rule.init.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.waf_regional.rate_based_rule.init.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="waf-regional",
        operation="list_rate_based_rules",
        op_kwargs={"NextMarker": next_marker, "Limit": limit},
    )


async def update(
    hub, ctx, rule_id: str, change_token: str, updates: List, rate_limit: int
) -> Dict:
    r"""
    **Autogenerated function**

     This is AWS WAF Classic documentation. For more information, see AWS WAF Classic in the developer guide.  For the latest version of AWS WAF, use the AWS WAFV2 API and see the AWS WAF Developer Guide. With the latest version, AWS WAF has a single set of endpoints for regional and global use.   Inserts or deletes Predicate objects in a rule and updates the RateLimit in the rule.  Each Predicate object identifies a predicate, such as a ByteMatchSet or an IPSet, that specifies the web requests that you want to block or count. The RateLimit specifies the number of requests every five minutes that triggers the rule. If you add more than one predicate to a RateBasedRule, a request must match all the predicates and exceed the RateLimit to be counted or blocked. For example, suppose you add the following to a RateBasedRule:   An IPSet that matches the IP address 192.0.2.44/32    A ByteMatchSet that matches BadBot in the User-Agent header   Further, you specify a RateLimit of 1,000. You then add the RateBasedRule to a WebACL and specify that you want to block requests that satisfy the rule. For a request to be blocked, it must come from the IP address 192.0.2.44 and the User-Agent header in the request must contain the value BadBot. Further, requests that match these two conditions much be received at a rate of more than 1,000 every five minutes. If the rate drops below this limit, AWS WAF no longer blocks the requests. As a second example, suppose you want to limit requests to a particular page on your site. To do this, you could add the following to a RateBasedRule:   A ByteMatchSet with FieldToMatch of URI    A PositionalConstraint of STARTS_WITH    A TargetString of login    Further, you specify a RateLimit of 1,000. By adding this RateBasedRule to a WebACL, you could limit requests to your login page without affecting the rest of your site.

    Args:
        rule_id(str): The RuleId of the RateBasedRule that you want to update. RuleId is returned by CreateRateBasedRule and by ListRateBasedRules.
        change_token(str): The value returned by the most recent call to GetChangeToken.
        updates(List): An array of RuleUpdate objects that you want to insert into or delete from a RateBasedRule. .
        rate_limit(int): The maximum number of requests, which have an identical value in the field specified by the RateKey, allowed in a five-minute period. If the number of requests exceeds the RateLimit and the other predicates specified in the rule are also met, AWS WAF triggers the action that is specified for this rule.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.waf_regional.rate_based_rule.init.update(
                ctx, rule_id=value, change_token=value, updates=value, rate_limit=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.waf_regional.rate_based_rule.init.update rule_id=value, change_token=value, updates=value, rate_limit=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="waf-regional",
        operation="update_rate_based_rule",
        op_kwargs={
            "RuleId": rule_id,
            "ChangeToken": change_token,
            "Updates": updates,
            "RateLimit": rate_limit,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def get(
    hub,
    ctx,
    name: str,
    block_address: Dict,
    document_id: str,
    digest_tip_address: Dict = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Returns a revision data object for a specified document ID and block address. Also returns a proof of the specified revision for verification if DigestTipAddress is provided.

    Args:
        name(str): The name of the ledger.
        block_address(Dict): The block location of the document revision to be verified. An address is an Amazon Ion structure that has two fields: strandId and sequenceNo. For example: {strandId:"BlFTjlSXze9BIh1KOszcE3",sequenceNo:14}.
        document_id(str): The UUID (represented in Base62-encoded text) of the document to be verified.
        digest_tip_address(Dict, optional): The latest block location covered by the digest for which to request a proof. An address is an Amazon Ion structure that has two fields: strandId and sequenceNo. For example: {strandId:"BlFTjlSXze9BIh1KOszcE3",sequenceNo:49}. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.qldb.revision.get(
                ctx, name=value, block_address=value, document_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.qldb.revision.get name=value, block_address=value, document_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="qldb",
        operation="get_revision",
        op_kwargs={
            "Name": name,
            "BlockAddress": block_address,
            "DocumentId": document_id,
            "DigestTipAddress": digest_tip_address,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def tag(hub, ctx, resource_arn: str, tags: Dict) -> Dict:
    r"""
    **Autogenerated function**

    Adds or overwrites the specified tags for the specified Amazon Managed Blockchain resource. Each tag consists of a key and optional value. When you specify a tag key that already exists, the tag value is overwritten with the new value. Use UntagResource to remove tag keys. A resource can have up to 50 tags. If you try to create more than 50 tags for a resource, your request fails and returns an error. For more information about tags, see Tagging Resources in the Amazon Managed Blockchain Ethereum Developer Guide, or Tagging Resources in the Amazon Managed Blockchain Hyperledger Fabric Developer Guide.

    Args:
        resource_arn(str): The Amazon Resource Name (ARN) of the resource. For more information about ARNs and their format, see Amazon Resource Names (ARNs) in the AWS General Reference.
        tags(Dict): The tags to assign to the specified resource. Tag values can be empty, for example, "MyTagKey" : "". You can specify multiple key-value pairs in a single request, with an overall maximum of 50 tags added to each resource.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.managedblockchain.resource.tag(
                ctx, resource_arn=value, tags=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.managedblockchain.resource.tag resource_arn=value, tags=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="managedblockchain",
        operation="tag_resource",
        op_kwargs={"ResourceArn": resource_arn, "Tags": tags},
    )


async def untag(hub, ctx, resource_arn: str, tag_keys: List) -> Dict:
    r"""
    **Autogenerated function**

    Removes the specified tags from the Amazon Managed Blockchain resource. For more information about tags, see Tagging Resources in the Amazon Managed Blockchain Ethereum Developer Guide, or Tagging Resources in the Amazon Managed Blockchain Hyperledger Fabric Developer Guide.

    Args:
        resource_arn(str): The Amazon Resource Name (ARN) of the resource. For more information about ARNs and their format, see Amazon Resource Names (ARNs) in the AWS General Reference.
        tag_keys(List): The tag keys.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.managedblockchain.resource.untag(
                ctx, resource_arn=value, tag_keys=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.managedblockchain.resource.untag resource_arn=value, tag_keys=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="managedblockchain",
        operation="untag_resource",
        op_kwargs={"ResourceArn": resource_arn, "TagKeys": tag_keys},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def list_all(
    hub,
    ctx,
    project_name: str,
    dataset_type: str,
    labeled: bool = None,
    anomaly_class: str = None,
    before_creation_date: str = None,
    after_creation_date: str = None,
    next_token: str = None,
    max_results: int = None,
    source_ref_contains: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Lists the JSON Lines within a dataset. An Amazon Lookout for Vision JSON Line contains the anomaly information for a single image, including the image location and the assigned label. This operation requires permissions to perform the lookoutvision:ListDatasetEntries operation.

    Args:
        project_name(str): The name of the project that contains the dataset that you want to list.
        dataset_type(str): The type of the dataset that you want to list. Specify train to list the training dataset. Specify test to list the test dataset. If you have a single dataset project, specify train.
        labeled(bool, optional): Specify true to include labeled entries, otherwise specify false. If you don't specify a value, Lookout for Vision returns all entries. Defaults to None.
        anomaly_class(str, optional): Specify normal to include only normal images. Specify anomaly to only include anomalous entries. If you don't specify a value, Amazon Lookout for Vision returns normal and anomalous images. Defaults to None.
        before_creation_date(str, optional): Only includes entries before the specified date in the response. For example, 2020-06-23T00:00:00. Defaults to None.
        after_creation_date(str, optional): Only includes entries after the specified date in the response. For example, 2020-06-23T00:00:00. Defaults to None.
        next_token(str, optional): If the previous response was incomplete (because there is more data to retrieve), Amazon Lookout for Vision returns a pagination token in the response. You can use this pagination token to retrieve the next set of dataset entries. Defaults to None.
        max_results(int, optional): The maximum number of results to return per paginated call. The largest value you can specify is 100. If you specify a value greater than 100, a ValidationException error occurs. The default value is 100. Defaults to None.
        source_ref_contains(str, optional): Perform a "contains" search on the values of the source-ref key within the dataset. For example a value of "IMG_17" returns all JSON Lines where the source-ref key value matches *IMG_17*. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.lookoutvision.dataset.entry.list_all(
                ctx, project_name=value, dataset_type=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.lookoutvision.dataset.entry.list_all project_name=value, dataset_type=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="lookoutvision",
        operation="list_dataset_entries",
        op_kwargs={
            "ProjectName": project_name,
            "DatasetType": dataset_type,
            "Labeled": labeled,
            "AnomalyClass": anomaly_class,
            "BeforeCreationDate": before_creation_date,
            "AfterCreationDate": after_creation_date,
            "NextToken": next_token,
            "MaxResults": max_results,
            "SourceRefContains": source_ref_contains,
        },
    )


async def update_multiple(
    hub,
    ctx,
    project_name: str,
    dataset_type: str,
    changes: bytes,
    client_token: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Adds one or more JSON Line entries to a dataset. A JSON Line includes information about an image used for training or testing an Amazon Lookout for Vision model. The following is an example JSON Line. Updating a dataset might take a while to complete. To check the current status, call DescribeDataset and check the Status field in the response. This operation requires permissions to perform the lookoutvision:UpdateDatasetEntries operation.

    Args:
        project_name(str): The name of the project that contains the dataset that you want to update.
        dataset_type(str): The type of the dataset that you want to update. Specify train to update the training dataset. Specify test to update the test dataset. If you have a single dataset project, specify train.
        changes(bytes): The entries to add to the dataset.
        client_token(str, optional): ClientToken is an idempotency token that ensures a call to UpdateDatasetEntries completes only once. You choose the value to pass. For example, An issue, such as an network outage, might prevent you from getting a response from UpdateDatasetEntries. In this case, safely retry your call to UpdateDatasetEntries by using the same ClientToken parameter value. An error occurs if the other input parameters are not the same as in the first request. Using a different value for ClientToken is considered a new call to UpdateDatasetEntries. An idempotency token is active for 8 hours. . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.lookoutvision.dataset.entry.update_multiple(
                ctx, project_name=value, dataset_type=value, changes=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.lookoutvision.dataset.entry.update_multiple project_name=value, dataset_type=value, changes=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="lookoutvision",
        operation="update_dataset_entries",
        op_kwargs={
            "ProjectName": project_name,
            "DatasetType": dataset_type,
            "Changes": changes,
            "ClientToken": client_token,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def test(
    hub,
    ctx,
    rest_api_id: str,
    resource_id: str,
    http_method: str,
    path_with_query_string: str = None,
    body: str = None,
    headers: Dict = None,
    multi_value_headers: Dict = None,
    client_certificate_id: str = None,
    stage_variables: Dict = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Simulate the execution of a Method in your RestApi with headers, parameters, and an incoming request body.

    Args:
        rest_api_id(str): [Required] The string identifier of the associated RestApi.
        resource_id(str): [Required] Specifies a test invoke method request's resource ID.
        http_method(str): [Required] Specifies a test invoke method request's HTTP method.
        path_with_query_string(str, optional): The URI path, including query string, of the simulated invocation request. Use this to specify path parameters and query string parameters. Defaults to None.
        body(str, optional): The simulated request body of an incoming invocation request. Defaults to None.
        headers(Dict, optional): A key-value map of headers to simulate an incoming invocation request. Defaults to None.
        multi_value_headers(Dict, optional): The headers as a map from string to list of values to simulate an incoming invocation request. Defaults to None.
        client_certificate_id(str, optional): A ClientCertificate identifier to use in the test invocation. API Gateway will use the certificate when making the HTTPS request to the defined back-end endpoint. Defaults to None.
        stage_variables(Dict, optional): A key-value map of stage variables to simulate an invocation on a deployed Stage. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.apigateway.invoke.method.test(
                ctx, rest_api_id=value, resource_id=value, http_method=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.apigateway.invoke.method.test rest_api_id=value, resource_id=value, http_method=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="apigateway",
        operation="test_invoke_method",
        op_kwargs={
            "restApiId": rest_api_id,
            "resourceId": resource_id,
            "httpMethod": http_method,
            "pathWithQueryString": path_with_query_string,
            "body": body,
            "headers": headers,
            "multiValueHeaders": multi_value_headers,
            "clientCertificateId": client_certificate_id,
            "stageVariables": stage_variables,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def get(
    hub,
    ctx,
    stream_name: str,
    shard_id: str,
    shard_iterator_type: str,
    starting_sequence_number: str = None,
    timestamp: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Gets an Amazon Kinesis shard iterator. A shard iterator expires 5 minutes after it is returned to the requester. A shard iterator specifies the shard position from which to start reading data records sequentially. The position is specified using the sequence number of a data record in a shard. A sequence number is the identifier associated with every record ingested in the stream, and is assigned when a record is put into the stream. Each stream has one or more shards. You must specify the shard iterator type. For example, you can set the ShardIteratorType parameter to read exactly from the position denoted by a specific sequence number by using the AT_SEQUENCE_NUMBER shard iterator type. Alternatively, the parameter can read right after the sequence number by using the AFTER_SEQUENCE_NUMBER shard iterator type, using sequence numbers returned by earlier calls to PutRecord, PutRecords, GetRecords, or DescribeStream. In the request, you can specify the shard iterator type AT_TIMESTAMP to read records from an arbitrary point in time, TRIM_HORIZON to cause ShardIterator to point to the last untrimmed record in the shard in the system (the oldest data record in the shard), or LATEST so that you always read the most recent data in the shard.  When you read repeatedly from a stream, use a GetShardIterator request to get the first shard iterator for use in your first GetRecords request and for subsequent reads use the shard iterator returned by the GetRecords request in NextShardIterator. A new shard iterator is returned by every GetRecords request in NextShardIterator, which you use in the ShardIterator parameter of the next GetRecords request.  If a GetShardIterator request is made too often, you receive a ProvisionedThroughputExceededException. For more information about throughput limits, see GetRecords, and Streams Limits in the Amazon Kinesis Data Streams Developer Guide. If the shard is closed, GetShardIterator returns a valid iterator for the last sequence number of the shard. A shard can be closed as a result of using SplitShard or MergeShards.  GetShardIterator has a limit of five transactions per second per account per open shard.

    Args:
        stream_name(str): The name of the Amazon Kinesis data stream.
        shard_id(str): The shard ID of the Kinesis Data Streams shard to get the iterator for.
        shard_iterator_type(str): Determines how the shard iterator is used to start reading data records from the shard. The following are the valid Amazon Kinesis shard iterator types:   AT_SEQUENCE_NUMBER - Start reading from the position denoted by a specific sequence number, provided in the value StartingSequenceNumber.   AFTER_SEQUENCE_NUMBER - Start reading right after the position denoted by a specific sequence number, provided in the value StartingSequenceNumber.   AT_TIMESTAMP - Start reading from the position denoted by a specific time stamp, provided in the value Timestamp.   TRIM_HORIZON - Start reading at the last untrimmed record in the shard in the system, which is the oldest data record in the shard.   LATEST - Start reading just after the most recent record in the shard, so that you always read the most recent data in the shard.  .
        starting_sequence_number(str, optional): The sequence number of the data record in the shard from which to start reading. Used with shard iterator type AT_SEQUENCE_NUMBER and AFTER_SEQUENCE_NUMBER. Defaults to None.
        timestamp(str, optional): The time stamp of the data record from which to start reading. Used with shard iterator type AT_TIMESTAMP. A time stamp is the Unix epoch date with precision in milliseconds. For example, 2016-04-04T19:58:46.480-00:00 or 1459799926.480. If a record with this exact time stamp does not exist, the iterator returned is for the next (later) record. If the time stamp is older than the current trim horizon, the iterator returned is for the oldest untrimmed data record (TRIM_HORIZON). Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.kinesis.shard.iterator.get(
                ctx, stream_name=value, shard_id=value, shard_iterator_type=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.kinesis.shard.iterator.get stream_name=value, shard_id=value, shard_iterator_type=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="kinesis",
        operation="get_shard_iterator",
        op_kwargs={
            "StreamName": stream_name,
            "ShardId": shard_id,
            "ShardIteratorType": shard_iterator_type,
            "StartingSequenceNumber": starting_sequence_number,
            "Timestamp": timestamp,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def tag(hub, ctx, resource_arn: str, tags: List) -> Dict:
    r"""
    **Autogenerated function**

     Associates the list of tags in the input Tags parameter with the resource identified by the ResourceArn input parameter.

    Args:
        resource_arn(str):  The ARN of a resource, such as a CodeDeploy application or deployment group. .
        tags(List):  A list of tags that TagResource associates with a resource. The resource is identified by the ResourceArn input parameter. .

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.codedeploy.resource.init.tag(
                ctx, resource_arn=value, tags=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.codedeploy.resource.init.tag resource_arn=value, tags=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="codedeploy",
        operation="tag_resource",
        op_kwargs={"ResourceArn": resource_arn, "Tags": tags},
    )


async def untag(hub, ctx, resource_arn: str, tag_keys: List) -> Dict:
    r"""
    **Autogenerated function**

     Disassociates a resource from a list of tags. The resource is identified by the ResourceArn input parameter. The tags are identified by the list of keys in the TagKeys input parameter.

    Args:
        resource_arn(str):  The Amazon Resource Name (ARN) that specifies from which resource to disassociate the tags with the keys in the TagKeys input parameter. .
        tag_keys(List):  A list of keys of Tag objects. The Tag objects identified by the keys are disassociated from the resource specified by the ResourceArn input parameter. .

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.codedeploy.resource.init.untag(
                ctx, resource_arn=value, tag_keys=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.codedeploy.resource.init.untag resource_arn=value, tag_keys=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="codedeploy",
        operation="untag_resource",
        op_kwargs={"ResourceArn": resource_arn, "TagKeys": tag_keys},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def estimate(
    hub,
    ctx,
    template_body: str = None,
    template_url: str = None,
    parameters: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Returns the estimated monthly cost of a template. The return value is an Amazon Web Services Simple Monthly Calculator URL with a query string that describes the resources required to run the template.

    Args:
        template_body(str, optional): Structure containing the template body with a minimum length of 1 byte and a maximum length of 51,200 bytes. (For more information, go to Template Anatomy in the CloudFormation User Guide.) Conditional: You must pass TemplateBody or TemplateURL. If both are passed, only TemplateBody is used. Defaults to None.
        template_url(str, optional): Location of file containing the template body. The URL must point to a template that is located in an Amazon S3 bucket or a Systems Manager document. For more information, go to Template Anatomy in the CloudFormation User Guide. Conditional: You must pass TemplateURL or TemplateBody. If both are passed, only TemplateBody is used. Defaults to None.
        parameters(List, optional): A list of Parameter structures that specify input parameters. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.cloudformation.template.cost.estimate(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.cloudformation.template.cost.estimate
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="cloudformation",
        operation="estimate_template_cost",
        op_kwargs={
            "TemplateBody": template_body,
            "TemplateURL": template_url,
            "Parameters": parameters,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import List


async def add(hub, ctx, resource_name: str, tags: List) -> None:
    r"""
    **Autogenerated function**

    Adds metadata tags to an Amazon RDS resource. These tags can also be used with cost allocation reporting to track cost associated with Amazon RDS resources, or used in a Condition statement in an IAM policy for Amazon RDS. For an overview on tagging Amazon RDS resources, see Tagging Amazon RDS Resources.

    Args:
        resource_name(str): The Amazon RDS resource that the tags are added to. This value is an Amazon Resource Name (ARN). For information about creating an ARN, see  Constructing an RDS Amazon Resource Name (ARN).
        tags(List): The tags to be assigned to the Amazon RDS resource.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.rds.tags.to_resource.add(ctx, resource_name=value, tags=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.rds.tags.to_resource.add resource_name=value, tags=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="rds",
        operation="add_tags_to_resource",
        op_kwargs={"ResourceName": resource_name, "Tags": tags},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def batch(
    hub, ctx, service_action_associations: List, accept_language: str = None
) -> Dict:
    r"""
    **Autogenerated function**

    Associates multiple self-service actions with provisioning artifacts.

    Args:
        service_action_associations(List): One or more associations, each consisting of the Action ID, the Product ID, and the Provisioning Artifact ID.
        accept_language(str, optional): The language code.    en - English (default)    jp - Japanese    zh - Chinese  . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.servicecatalog.associate_service_action_with_provisioning_artifact.batch(
                ctx, service_action_associations=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.servicecatalog.associate_service_action_with_provisioning_artifact.batch service_action_associations=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="servicecatalog",
        operation="batch_associate_service_action_with_provisioning_artifact",
        op_kwargs={
            "ServiceActionAssociations": service_action_associations,
            "AcceptLanguage": accept_language,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub,
    ctx,
    certificate_name: str,
    domain_name: str,
    subject_alternative_names: List = None,
    tags: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates an SSL/TLS certificate for an Amazon Lightsail content delivery network (CDN) distribution and a container service. After the certificate is valid, use the AttachCertificateToDistribution action to use the certificate and its domains with your distribution. Or use the UpdateContainerService action to use the certificate and its domains with your container service.  Only certificates created in the us-east-1 AWS Region can be attached to Lightsail distributions. Lightsail distributions are global resources that can reference an origin in any AWS Region, and distribute its content globally. However, all distributions are located in the us-east-1 Region.

    Args:
        certificate_name(str): The name for the certificate.
        domain_name(str): The domain name (e.g., example.com) for the certificate.
        subject_alternative_names(List, optional): An array of strings that specify the alternate domains (e.g., example2.com) and subdomains (e.g., blog.example.com) for the certificate. You can specify a maximum of nine alternate domains (in addition to the primary domain name). Wildcard domain entries (e.g., *.example.com) are not supported. Defaults to None.
        tags(List, optional): The tag keys and optional values to add to the certificate during create. Use the TagResource action to tag a resource after it's created. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.lightsail.certificate.init.create(
                ctx, certificate_name=value, domain_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.lightsail.certificate.init.create certificate_name=value, domain_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="lightsail",
        operation="create_certificate",
        op_kwargs={
            "certificateName": certificate_name,
            "domainName": domain_name,
            "subjectAlternativeNames": subject_alternative_names,
            "tags": tags,
        },
    )


async def delete(hub, ctx, certificate_name: str) -> Dict:
    r"""
    **Autogenerated function**

    Deletes an SSL/TLS certificate for your Amazon Lightsail content delivery network (CDN) distribution. Certificates that are currently attached to a distribution cannot be deleted. Use the DetachCertificateFromDistribution action to detach a certificate from a distribution.

    Args:
        certificate_name(str): The name of the certificate to delete. Use the GetCertificates action to get a list of certificate names that you can specify.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.lightsail.certificate.init.delete(ctx, certificate_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.lightsail.certificate.init.delete certificate_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="lightsail",
        operation="delete_certificate",
        op_kwargs={"certificateName": certificate_name},
    )


async def get_all(
    hub,
    ctx,
    certificate_statuses: List = None,
    include_certificate_details: bool = None,
    certificate_name: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Returns information about one or more Amazon Lightsail SSL/TLS certificates.  To get a summary of a certificate, ommit includeCertificateDetails from your request. The response will include only the certificate Amazon Resource Name (ARN), certificate name, domain name, and tags.

    Args:
        certificate_statuses(List, optional): The status of the certificates for which to return information. For example, specify ISSUED to return only certificates with an ISSUED status. When omitted, the response includes all of your certificates in the AWS Region where the request is made, regardless of their current status. Defaults to None.
        include_certificate_details(bool, optional): Indicates whether to include detailed information about the certificates in the response. When omitted, the response includes only the certificate names, Amazon Resource Names (ARNs), domain names, and tags. Defaults to None.
        certificate_name(str, optional): The name for the certificate for which to return information. When omitted, the response includes all of your certificates in the AWS Region where the request is made. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.lightsail.certificate.init.get_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.lightsail.certificate.init.get_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="lightsail",
        operation="get_certificates",
        op_kwargs={
            "certificateStatuses": certificate_statuses,
            "includeCertificateDetails": include_certificate_details,
            "certificateName": certificate_name,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def update(
    hub, ctx, name: str, version: str, client_request_token: str = None
) -> Dict:
    r"""
    **Autogenerated function**

    Updates an Amazon EKS cluster to the specified Kubernetes version. Your cluster continues to function during the update. The response output includes an update ID that you can use to track the status of your cluster update with the DescribeUpdate API operation. Cluster updates are asynchronous, and they should finish within a few minutes. During an update, the cluster status moves to UPDATING (this status transition is eventually consistent). When the update is complete (either Failed or Successful), the cluster status moves to Active. If your cluster has managed node groups attached to it, all of your node groups’ Kubernetes versions must match the cluster’s Kubernetes version in order to update the cluster to a new Kubernetes version.

    Args:
        name(str): The name of the Amazon EKS cluster to update.
        version(str): The desired Kubernetes version following a successful update.
        client_request_token(str, optional): Unique, case-sensitive identifier that you provide to ensure the idempotency of the request. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.eks.cluster.version.update(ctx, name=value, version=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.eks.cluster.version.update name=value, version=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="eks",
        operation="update_cluster_version",
        op_kwargs={
            "name": name,
            "version": version,
            "clientRequestToken": client_request_token,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def get_all(
    hub,
    ctx,
    filters: Dict = None,
    sort_criteria: List = None,
    next_token: str = None,
    max_results: int = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Returns a list of findings that match the specified criteria.

    Args:
        filters(Dict, optional): The finding attributes used to define a condition to filter the returned findings. You can filter by up to 10 finding attributes. For each attribute, you can provide up to 20 filter values. Note that in the available filter fields, WorkflowState is deprecated. To search for a finding based on its workflow status, use WorkflowStatus. Defaults to None.
        sort_criteria(List, optional): The finding attributes used to sort the list of returned findings. Defaults to None.
        next_token(str, optional): The token that is required for pagination. On your first call to the GetFindings operation, set the value of this parameter to NULL. For subsequent calls to the operation, to continue listing data, set the value of this parameter to the value returned from the previous response. Defaults to None.
        max_results(int, optional): The maximum number of findings to return. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.securityhub.finding.get_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.securityhub.finding.get_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="securityhub",
        operation="get_findings",
        op_kwargs={
            "Filters": filters,
            "SortCriteria": sort_criteria,
            "NextToken": next_token,
            "MaxResults": max_results,
        },
    )


async def update_multiple(
    hub, ctx, filters: Dict, note: Dict = None, record_state: str = None
) -> Dict:
    r"""
    **Autogenerated function**

     UpdateFindings is deprecated. Instead of UpdateFindings, use BatchUpdateFindings. Updates the Note and RecordState of the Security Hub-aggregated findings that the filter attributes specify. Any member account that can view the finding also sees the update to the finding.

    Args:
        filters(Dict): A collection of attributes that specify which findings you want to update.
        note(Dict, optional): The updated note for the finding. Defaults to None.
        record_state(str, optional): The updated record state for the finding. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.securityhub.finding.update_multiple(ctx, filters=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.securityhub.finding.update_multiple filters=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="securityhub",
        operation="update_findings",
        op_kwargs={"Filters": filters, "Note": note, "RecordState": record_state},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def create(
    hub, ctx, account_id: str, name: str, client_request_token: str = None
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a chat room for the specified Amazon Chime Enterprise account.

    Args:
        account_id(str): The Amazon Chime account ID.
        name(str): The room name.
        client_request_token(str, optional): The idempotency token for the request. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.chime.room.init.create(ctx, account_id=value, name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.chime.room.init.create account_id=value, name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="chime",
        operation="create_room",
        op_kwargs={
            "AccountId": account_id,
            "Name": name,
            "ClientRequestToken": client_request_token,
        },
    )


async def delete(hub, ctx, account_id: str, room_id: str) -> None:
    r"""
    **Autogenerated function**

    Deletes a chat room in an Amazon Chime Enterprise account.

    Args:
        account_id(str): The Amazon Chime account ID.
        room_id(str): The chat room ID.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.chime.room.init.delete(ctx, account_id=value, room_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.chime.room.init.delete account_id=value, room_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="chime",
        operation="delete_room",
        op_kwargs={"AccountId": account_id, "RoomId": room_id},
    )


async def get(hub, ctx, account_id: str, room_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Retrieves room details, such as the room name, for a room in an Amazon Chime Enterprise account.

    Args:
        account_id(str): The Amazon Chime account ID.
        room_id(str): The room ID.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.chime.room.init.get(ctx, account_id=value, room_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.chime.room.init.get account_id=value, room_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="chime",
        operation="get_room",
        op_kwargs={"AccountId": account_id, "RoomId": room_id},
    )


async def list_all(
    hub,
    ctx,
    account_id: str,
    member_id: str = None,
    max_results: int = None,
    next_token: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Lists the room details for the specified Amazon Chime Enterprise account. Optionally, filter the results by a member ID (user ID or bot ID) to see a list of rooms that the member belongs to.

    Args:
        account_id(str): The Amazon Chime account ID.
        member_id(str, optional): The member ID (user ID or bot ID). Defaults to None.
        max_results(int, optional): The maximum number of results to return in a single call. Defaults to None.
        next_token(str, optional): The token to use to retrieve the next page of results. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.chime.room.init.list_all(ctx, account_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.chime.room.init.list_all account_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="chime",
        operation="list_rooms",
        op_kwargs={
            "AccountId": account_id,
            "MemberId": member_id,
            "MaxResults": max_results,
            "NextToken": next_token,
        },
    )


async def update(hub, ctx, account_id: str, room_id: str, name: str = None) -> Dict:
    r"""
    **Autogenerated function**

    Updates room details, such as the room name, for a room in an Amazon Chime Enterprise account.

    Args:
        account_id(str): The Amazon Chime account ID.
        room_id(str): The room ID.
        name(str, optional): The room name. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.chime.room.init.update(ctx, account_id=value, room_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.chime.room.init.update account_id=value, room_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="chime",
        operation="update_room",
        op_kwargs={"AccountId": account_id, "RoomId": room_id, "Name": name},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def create(
    hub, ctx, vocabulary_name: str, language_code: str, vocabulary_file_uri: str
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a new custom vocabulary that you can use to change how Amazon Transcribe Medical transcribes your audio file.

    Args:
        vocabulary_name(str): The name of the custom vocabulary. This case-sensitive name must be unique within an AWS account. If you try to create a vocabulary with the same name as a previous vocabulary, you get a ConflictException error.
        language_code(str): The language code for the language used for the entries in your custom vocabulary. The language code of your custom vocabulary must match the language code of your transcription job. US English (en-US) is the only language code available for Amazon Transcribe Medical.
        vocabulary_file_uri(str): The location in Amazon S3 of the text file you use to define your custom vocabulary. The URI must be in the same AWS Region as the resource that you're calling. Enter information about your VocabularyFileUri in the following format:   https://s3.<aws-region>.amazonaws.com/<bucket-name>/<keyprefix>/<objectkey>   The following is an example URI for a vocabulary file that is stored in Amazon S3:  https://s3.us-east-1.amazonaws.com/AWSDOC-EXAMPLE-BUCKET/vocab.txt  For more information about Amazon S3 object names, see Object Keys in the Amazon S3 Developer Guide. For more information about custom vocabularies, see Medical Custom Vocabularies.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.transcribe.medical.vocabulary.create(
                ctx, vocabulary_name=value, language_code=value, vocabulary_file_uri=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.transcribe.medical.vocabulary.create vocabulary_name=value, language_code=value, vocabulary_file_uri=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="transcribe",
        operation="create_medical_vocabulary",
        op_kwargs={
            "VocabularyName": vocabulary_name,
            "LanguageCode": language_code,
            "VocabularyFileUri": vocabulary_file_uri,
        },
    )


async def delete(hub, ctx, vocabulary_name: str) -> None:
    r"""
    **Autogenerated function**

    Deletes a vocabulary from Amazon Transcribe Medical.

    Args:
        vocabulary_name(str): The name of the vocabulary that you want to delete.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.transcribe.medical.vocabulary.delete(ctx, vocabulary_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.transcribe.medical.vocabulary.delete vocabulary_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="transcribe",
        operation="delete_medical_vocabulary",
        op_kwargs={"VocabularyName": vocabulary_name},
    )


async def get(hub, ctx, vocabulary_name: str) -> Dict:
    r"""
    **Autogenerated function**

    Retrieves information about a medical vocabulary.

    Args:
        vocabulary_name(str): The name of the vocabulary that you want information about. The value is case sensitive. .

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.transcribe.medical.vocabulary.get(ctx, vocabulary_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.transcribe.medical.vocabulary.get vocabulary_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="transcribe",
        operation="get_medical_vocabulary",
        op_kwargs={"VocabularyName": vocabulary_name},
    )


async def list_all(
    hub,
    ctx,
    next_token: str = None,
    max_results: int = None,
    state_equals: str = None,
    name_contains: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Returns a list of vocabularies that match the specified criteria. If you don't enter a value in any of the request parameters, returns the entire list of vocabularies.

    Args:
        next_token(str, optional): If the result of your previous request to ListMedicalVocabularies was truncated, include the NextToken to fetch the next set of vocabularies. Defaults to None.
        max_results(int, optional): The maximum number of vocabularies to return in the response. Defaults to None.
        state_equals(str, optional): When specified, returns only vocabularies with the VocabularyState equal to the specified vocabulary state. Use this field to see which vocabularies are ready for your medical transcription jobs. Defaults to None.
        name_contains(str, optional): Returns vocabularies whose names contain the specified string. The search is not case sensitive. ListMedicalVocabularies returns both "vocabularyname" and "VocabularyName". Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.transcribe.medical.vocabulary.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.transcribe.medical.vocabulary.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="transcribe",
        operation="list_medical_vocabularies",
        op_kwargs={
            "NextToken": next_token,
            "MaxResults": max_results,
            "StateEquals": state_equals,
            "NameContains": name_contains,
        },
    )


async def update(
    hub, ctx, vocabulary_name: str, language_code: str, vocabulary_file_uri: str = None
) -> Dict:
    r"""
    **Autogenerated function**

    Updates a vocabulary with new values that you provide in a different text file from the one you used to create the vocabulary. The UpdateMedicalVocabulary operation overwrites all of the existing information with the values that you provide in the request.

    Args:
        vocabulary_name(str): The name of the vocabulary to update. The name is case sensitive. If you try to update a vocabulary with the same name as a vocabulary you've already made, you get a ConflictException error.
        language_code(str): The language code of the language used for the entries in the updated vocabulary. US English (en-US) is the only valid language code in Amazon Transcribe Medical.
        vocabulary_file_uri(str, optional): The location in Amazon S3 of the text file that contains the you use for your custom vocabulary. The URI must be in the same AWS Region as the resource that you are calling. The following is the format for a URI:   https://s3.<aws-region>.amazonaws.com/<bucket-name>/<keyprefix>/<objectkey>   For example:  https://s3.us-east-1.amazonaws.com/AWSDOC-EXAMPLE-BUCKET/vocab.txt  For more information about Amazon S3 object names, see Object Keys in the Amazon S3 Developer Guide. For more information about custom vocabularies in Amazon Transcribe Medical, see Medical Custom Vocabularies. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.transcribe.medical.vocabulary.update(
                ctx, vocabulary_name=value, language_code=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.transcribe.medical.vocabulary.update vocabulary_name=value, language_code=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="transcribe",
        operation="update_medical_vocabulary",
        op_kwargs={
            "VocabularyName": vocabulary_name,
            "LanguageCode": language_code,
            "VocabularyFileUri": vocabulary_file_uri,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def restore(hub, ctx, public_ip: str, dry_run: bool = None) -> Dict:
    r"""
    **Autogenerated function**

    Restores an Elastic IP address that was previously moved to the EC2-VPC platform back to the EC2-Classic platform. You cannot move an Elastic IP address that was originally allocated for use in EC2-VPC. The Elastic IP address must not be associated with an instance or network interface.

    Args:
        dry_run(bool, optional): Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation. Defaults to None.
        public_ip(str): The Elastic IP address.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ec2.address.to.classic.restore(ctx, public_ip=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ec2.address.to.classic.restore public_ip=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ec2",
        operation="restore_address_to_classic",
        op_kwargs={"DryRun": dry_run, "PublicIp": public_ip},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


__virtualname__ = "custom_action_type"


async def create(
    hub,
    ctx,
    category: str,
    provider: str,
    version: str,
    input_artifact_details: Dict,
    output_artifact_details: Dict,
    settings: Dict = None,
    configuration_properties: List = None,
    tags: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a new custom action that can be used in all pipelines associated with the AWS account. Only used for custom actions.

    Args:
        category(str): The category of the custom action, such as a build action or a test action.
        provider(str): The provider of the service used in the custom action, such as AWS CodeDeploy.
        version(str): The version identifier of the custom action.
        settings(Dict, optional): URLs that provide users information about this custom action. Defaults to None.
        configuration_properties(List, optional): The configuration properties for the custom action.  You can refer to a name in the configuration properties of the custom action within the URL templates by following the format of {Config:name}, as long as the configuration property is both required and not secret. For more information, see Create a Custom Action for a Pipeline. . Defaults to None.
        input_artifact_details(Dict): The details of the input artifact for the action, such as its commit ID.
        output_artifact_details(Dict): The details of the output artifact of the action, such as its commit ID.
        tags(List, optional): The tags for the custom action. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.codepipeline.custom_action_type_.create(
                ctx,
                category=value,
                provider=value,
                version=value,
                input_artifact_details=value,
                output_artifact_details=value,
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.codepipeline.custom_action_type.create category=value, provider=value, version=value, input_artifact_details=value, output_artifact_details=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="codepipeline",
        operation="create_custom_action_type",
        op_kwargs={
            "category": category,
            "provider": provider,
            "version": version,
            "settings": settings,
            "configurationProperties": configuration_properties,
            "inputArtifactDetails": input_artifact_details,
            "outputArtifactDetails": output_artifact_details,
            "tags": tags,
        },
    )


async def delete(hub, ctx, category: str, provider: str, version: str) -> None:
    r"""
    **Autogenerated function**

    Marks a custom action as deleted. PollForJobs for the custom action fails after the action is marked for deletion. Used for custom actions only.  To re-create a custom action after it has been deleted you must use a string in the version field that has never been used before. This string can be an incremented version number, for example. To restore a deleted custom action, use a JSON file that is identical to the deleted action, including the original string in the version field.

    Args:
        category(str): The category of the custom action that you want to delete, such as source or deploy.
        provider(str): The provider of the service used in the custom action, such as AWS CodeDeploy.
        version(str): The version of the custom action to delete.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.codepipeline.custom_action_type_.delete(
                ctx, category=value, provider=value, version=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.codepipeline.custom_action_type.delete category=value, provider=value, version=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="codepipeline",
        operation="delete_custom_action_type",
        op_kwargs={"category": category, "provider": provider, "version": version},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def tag(hub, ctx, resource_arn: str, tags: Dict) -> Dict:
    r"""
    **Autogenerated function**

    Adds one or more tags to a specified Amazon QLDB resource. A resource can have up to 50 tags. If you try to create more than 50 tags for a resource, your request fails and returns an error.

    Args:
        resource_arn(str): The Amazon Resource Name (ARN) to which you want to add the tags. For example:  arn:aws:qldb:us-east-1:123456789012:ledger/exampleLedger .
        tags(Dict): The key-value pairs to add as tags to the specified QLDB resource. Tag keys are case sensitive. If you specify a key that already exists for the resource, your request fails and returns an error. Tag values are case sensitive and can be null.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.qldb.resource.tag(ctx, resource_arn=value, tags=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.qldb.resource.tag resource_arn=value, tags=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="qldb",
        operation="tag_resource",
        op_kwargs={"ResourceArn": resource_arn, "Tags": tags},
    )


async def untag(hub, ctx, resource_arn: str, tag_keys: List) -> Dict:
    r"""
    **Autogenerated function**

    Removes one or more tags from a specified Amazon QLDB resource. You can specify up to 50 tag keys to remove.

    Args:
        resource_arn(str): The Amazon Resource Name (ARN) from which to remove the tags. For example:  arn:aws:qldb:us-east-1:123456789012:ledger/exampleLedger .
        tag_keys(List): The list of tag keys to remove.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.qldb.resource.untag(ctx, resource_arn=value, tag_keys=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.qldb.resource.untag resource_arn=value, tag_keys=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="qldb",
        operation="untag_resource",
        op_kwargs={"ResourceArn": resource_arn, "TagKeys": tag_keys},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def create(
    hub, ctx, name: str, client_token: str, description: str = None, tags: Dict = None
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a new application that is the top-level node in a hierarchy of related cloud resource abstractions.

    Args:
        name(str): The name of the application. The name must be unique in the region in which you are creating the application.
        description(str, optional): The description of the application. Defaults to None.
        tags(Dict, optional): Key-value pairs you can use to associate with the application. Defaults to None.
        client_token(str): A unique identifier that you provide to ensure idempotency. If you retry a request that completed successfully using the same client token and the same parameters, the retry succeeds without performing any further actions. If you retry a successful request using the same client token, but one or more of the parameters are different, the retry fails.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.servicecatalog_appregistry.application.create(
                ctx, name=value, client_token=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.servicecatalog_appregistry.application.create name=value, client_token=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="servicecatalog-appregistry",
        operation="create_application",
        op_kwargs={
            "name": name,
            "description": description,
            "tags": tags,
            "clientToken": client_token,
        },
    )


async def delete(hub, ctx, application: str) -> Dict:
    r"""
    **Autogenerated function**

    Deletes an application that is specified either by its application ID or name. All associated attribute groups and resources must be disassociated from it before deleting an application.

    Args:
        application(str): The name or ID of the application.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.servicecatalog_appregistry.application.delete(
                ctx, application=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.servicecatalog_appregistry.application.delete application=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="servicecatalog-appregistry",
        operation="delete_application",
        op_kwargs={"application": application},
    )


async def get(hub, ctx, application: str) -> Dict:
    r"""
    **Autogenerated function**

    Retrieves metadata information about one of your applications. The application can be specified either by its unique ID or by its name (which is unique within one account in one region at a given point in time). Specify by ID in automated workflows if you want to make sure that the exact same application is returned or a ResourceNotFoundException is thrown, avoiding the ABA addressing problem.

    Args:
        application(str): The name or ID of the application.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.servicecatalog_appregistry.application.get(
                ctx, application=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.servicecatalog_appregistry.application.get application=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="servicecatalog-appregistry",
        operation="get_application",
        op_kwargs={"application": application},
    )


async def list_all(hub, ctx, next_token: str = None, max_results: int = None) -> Dict:
    r"""
    **Autogenerated function**

    Retrieves a list of all of your applications. Results are paginated.

    Args:
        next_token(str, optional): The token to use to get the next page of results after a previous API call. . Defaults to None.
        max_results(int, optional): The upper bound of the number of results to return (cannot exceed 25). If this parameter is omitted, it defaults to 25. This value is optional. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.servicecatalog_appregistry.application.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.servicecatalog_appregistry.application.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="servicecatalog-appregistry",
        operation="list_applications",
        op_kwargs={"nextToken": next_token, "maxResults": max_results},
    )


async def update(
    hub, ctx, application: str, name: str = None, description: str = None
) -> Dict:
    r"""
    **Autogenerated function**

    Updates an existing application with new attributes.

    Args:
        application(str): The name or ID of the application that will be updated.
        name(str, optional): The new name of the application. The name must be unique in the region in which you are updating the application. Defaults to None.
        description(str, optional): The new description of the application. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.servicecatalog_appregistry.application.update(
                ctx, application=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.servicecatalog_appregistry.application.update application=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="servicecatalog-appregistry",
        operation="update_application",
        op_kwargs={
            "application": application,
            "name": name,
            "description": description,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub,
    ctx,
    job_definition_name: str,
    model_quality_app_specification: Dict,
    model_quality_job_input: Dict,
    model_quality_job_output_config: Dict,
    job_resources: Dict,
    role_arn: str,
    model_quality_baseline_config: Dict = None,
    network_config: Dict = None,
    stopping_condition: Dict = None,
    tags: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a definition for a job that monitors model quality and drift. For information about model monitor, see Amazon SageMaker Model Monitor.

    Args:
        job_definition_name(str): The name of the monitoring job definition.
        model_quality_baseline_config(Dict, optional): Specifies the constraints and baselines for the monitoring job. Defaults to None.
        model_quality_app_specification(Dict): The container that runs the monitoring job.
        model_quality_job_input(Dict): A list of the inputs that are monitored. Currently endpoints are supported.
        model_quality_job_output_config(Dict): The output configuration for monitoring jobs.
        job_resources(Dict): Identifies the resources to deploy for a monitoring job.
        network_config(Dict, optional): Specifies the network configuration for the monitoring job. Defaults to None.
        role_arn(str): The Amazon Resource Name (ARN) of an IAM role that Amazon SageMaker can assume to perform tasks on your behalf.
        stopping_condition(Dict, optional): A time limit for how long the monitoring job is allowed to run before stopping. Defaults to None.
        tags(List, optional): (Optional) An array of key-value pairs. For more information, see Using Cost Allocation Tags in the Amazon Web Services Billing and Cost Management User Guide. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.sagemaker.model.quality_job_definition.create(
                ctx,
                job_definition_name=value,
                model_quality_app_specification=value,
                model_quality_job_input=value,
                model_quality_job_output_config=value,
                job_resources=value,
                role_arn=value,
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.sagemaker.model.quality_job_definition.create job_definition_name=value, model_quality_app_specification=value, model_quality_job_input=value, model_quality_job_output_config=value, job_resources=value, role_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="sagemaker",
        operation="create_model_quality_job_definition",
        op_kwargs={
            "JobDefinitionName": job_definition_name,
            "ModelQualityBaselineConfig": model_quality_baseline_config,
            "ModelQualityAppSpecification": model_quality_app_specification,
            "ModelQualityJobInput": model_quality_job_input,
            "ModelQualityJobOutputConfig": model_quality_job_output_config,
            "JobResources": job_resources,
            "NetworkConfig": network_config,
            "RoleArn": role_arn,
            "StoppingCondition": stopping_condition,
            "Tags": tags,
        },
    )


async def delete(hub, ctx, job_definition_name: str) -> None:
    r"""
    **Autogenerated function**

    Deletes the secified model quality monitoring job definition.

    Args:
        job_definition_name(str): The name of the model quality monitoring job definition to delete.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.sagemaker.model.quality_job_definition.delete(
                ctx, job_definition_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.sagemaker.model.quality_job_definition.delete job_definition_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="sagemaker",
        operation="delete_model_quality_job_definition",
        op_kwargs={"JobDefinitionName": job_definition_name},
    )


async def describe(hub, ctx, job_definition_name: str) -> Dict:
    r"""
    **Autogenerated function**

    Returns a description of a model quality job definition.

    Args:
        job_definition_name(str): The name of the model quality job. The name must be unique within an Amazon Web Services Region in the Amazon Web Services account.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.sagemaker.model.quality_job_definition.describe(
                ctx, job_definition_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.sagemaker.model.quality_job_definition.describe job_definition_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="sagemaker",
        operation="describe_model_quality_job_definition",
        op_kwargs={"JobDefinitionName": job_definition_name},
    )


async def list_all(
    hub,
    ctx,
    endpoint_name: str = None,
    sort_by: str = None,
    sort_order: str = None,
    next_token: str = None,
    max_results: int = None,
    name_contains: str = None,
    creation_time_before: str = None,
    creation_time_after: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Gets a list of model quality monitoring job definitions in your account.

    Args:
        endpoint_name(str, optional): A filter that returns only model quality monitoring job definitions that are associated with the specified endpoint. Defaults to None.
        sort_by(str, optional): The field to sort results by. The default is CreationTime. Defaults to None.
        sort_order(str, optional): The sort order for results. The default is Descending. Defaults to None.
        next_token(str, optional): If the result of the previous ListModelQualityJobDefinitions request was truncated, the response includes a NextToken. To retrieve the next set of model quality monitoring job definitions, use the token in the next request. Defaults to None.
        max_results(int, optional): The maximum number of results to return in a call to ListModelQualityJobDefinitions. Defaults to None.
        name_contains(str, optional): A string in the transform job name. This filter returns only model quality monitoring job definitions whose name contains the specified string. Defaults to None.
        creation_time_before(str, optional): A filter that returns only model quality monitoring job definitions created before the specified time. Defaults to None.
        creation_time_after(str, optional): A filter that returns only model quality monitoring job definitions created after the specified time. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.sagemaker.model.quality_job_definition.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.sagemaker.model.quality_job_definition.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="sagemaker",
        operation="list_model_quality_job_definitions",
        op_kwargs={
            "EndpointName": endpoint_name,
            "SortBy": sort_by,
            "SortOrder": sort_order,
            "NextToken": next_token,
            "MaxResults": max_results,
            "NameContains": name_contains,
            "CreationTimeBefore": creation_time_before,
            "CreationTimeAfter": creation_time_after,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def describe_all(
    hub, ctx, job_id: str, max_results: int = None, next_token: str = None
) -> Dict:
    r"""
    **Autogenerated function**

    Retrieves detailed Job log with paging.

    Args:
        job_id(str): Request to describe Job log job ID.
        max_results(int, optional): Request to describe Job log item maximum results. Defaults to None.
        next_token(str, optional): Request to describe Job log next token. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.mgn.job.log_item.describe_all(ctx, job_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.mgn.job.log_item.describe_all job_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="mgn",
        operation="describe_job_log_items",
        op_kwargs={"jobID": job_id, "maxResults": max_results, "nextToken": next_token},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


__virtualname__ = "parameter_for_import"


async def get(
    hub, ctx, key_id: str, wrapping_algorithm: str, wrapping_key_spec: str
) -> Dict:
    r"""
    **Autogenerated function**

    Returns the items you need to import key material into a symmetric, customer managed customer master key (CMK). For more information about importing key material into AWS KMS, see Importing Key Material in the AWS Key Management Service Developer Guide. This operation returns a public key and an import token. Use the public key to encrypt the symmetric key material. Store the import token to send with a subsequent ImportKeyMaterial request. You must specify the key ID of the symmetric CMK into which you will import key material. This CMK's Origin must be EXTERNAL. You must also specify the wrapping algorithm and type of wrapping key (public key) that you will use to encrypt the key material. You cannot perform this operation on an asymmetric CMK or on any CMK in a different AWS account. To import key material, you must use the public key and import token from the same response. These items are valid for 24 hours. The expiration date and time appear in the GetParametersForImport response. You cannot use an expired token in an ImportKeyMaterial request. If your key and token expire, send another GetParametersForImport request. The CMK that you use for this operation must be in a compatible key state. For details, see Key state: Effect on your CMK in the AWS Key Management Service Developer Guide.  Cross-account use: No. You cannot perform this operation on a CMK in a different AWS account.  Required permissions: kms:GetParametersForImport (key policy)  Related operations:     ImportKeyMaterial     DeleteImportedKeyMaterial

    Args:
        key_id(str): The identifier of the symmetric CMK into which you will import key material. The Origin of the CMK must be EXTERNAL. Specify the key ID or key ARN of the CMK. For example:   Key ID: 1234abcd-12ab-34cd-56ef-1234567890ab    Key ARN: arn:aws:kms:us-east-2:111122223333:key/1234abcd-12ab-34cd-56ef-1234567890ab    To get the key ID and key ARN for a CMK, use ListKeys or DescribeKey.
        wrapping_algorithm(str): The algorithm you will use to encrypt the key material before importing it with ImportKeyMaterial. For more information, see Encrypt the Key Material in the AWS Key Management Service Developer Guide.
        wrapping_key_spec(str): The type of wrapping key (public key) to return in the response. Only 2048-bit RSA public keys are supported.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.kms.parameter_for_import_.get(
                ctx, key_id=value, wrapping_algorithm=value, wrapping_key_spec=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.kms.parameter_for_import.get key_id=value, wrapping_algorithm=value, wrapping_key_spec=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="kms",
        operation="get_parameters_for_import",
        op_kwargs={
            "KeyId": key_id,
            "WrappingAlgorithm": wrapping_algorithm,
            "WrappingKeySpec": wrapping_key_spec,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def batch(
    hub,
    ctx,
    channel_arn: str,
    member_arns: List,
    type_: str = None,
    chime_bearer: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Adds a specified number of users to a channel.

    Args:
        channel_arn(str): The ARN of the channel to which you're adding users.
        type_(str, optional): The membership type of a user, DEFAULT or HIDDEN. Default members are always returned as part of ListChannelMemberships. Hidden members are only returned if the type filter in ListChannelMemberships equals HIDDEN. Otherwise hidden members are not returned. This is only supported by moderators. Defaults to None.
        member_arns(List): The ARNs of the members you want to add to the channel.
        chime_bearer(str, optional): The AppInstanceUserArn of the user that makes the API call. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.chime.create.channel_membership.batch(
                ctx, channel_arn=value, member_arns=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.chime.create.channel_membership.batch channel_arn=value, member_arns=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="chime",
        operation="batch_create_channel_membership",
        op_kwargs={
            "ChannelArn": channel_arn,
            "Type": type_,
            "MemberArns": member_arns,
            "ChimeBearer": chime_bearer,
        },
    )
